@@ -69,8 +69,8 @@
 #include <kio/netaccess.h>
 #include <kprogress.h>
 #include <kwin.h>
-#include <ktar.h>
 #include <kdeversion.h>
+#include <ktempfile.h>
 
 #include <qfileinfo.h>
 #include <qdir.h>
@@ -489,18 +489,18 @@ void CatalogManagerView::loadMarks()
     // test validity of list items
     QStringList testedList;
     QStringList::const_iterator it;
-    for( it=newMarkerList.begin() ; it!=newMarkerList.end() ; ++it )
+    for( it=newMarkerList.constBegin() ; it!=newMarkerList.constEnd() ; ++it )
 	if( _fileList[(*it)] != 0 ) testedList.append( (*it) );
 
     // apply new list
-    for( it=_markerList.begin() ; it!=_markerList.end() ; ++it )
+    for( it=_markerList.constBegin() ; it!=_markerList.constEnd() ; ++it )
     {
 	CatManListItem* item = _fileList[(*it)];
 	if( item ) item->setMarked(false);
     }
 
     _markerList = testedList;
-    for( it=_markerList.begin() ; it!=_markerList.end() ; ++it )
+    for( it=_markerList.constBegin() ; it!=_markerList.constEnd() ; ++it )
     {
 	CatManListItem* item = _fileList[(*it)];
 	if( item ) item->setMarked(true);
@@ -511,52 +511,90 @@ void CatalogManagerView::loadMarks()
 
 void CatalogManagerView::saveMarks()
 {
-    const KURL url = KFileDialog::getSaveURL( QString(), "*.marklist", this );
-    if( url.isEmpty() ) return;
+    const KURL url2 = KFileDialog::getSaveURL( QString(), "*.marklist", this );
+    if( url2.isEmpty() ) return;
 
-    if ( KIO::NetAccess::exists( url, false, this ) )
+    // ### FIXME: why is the file dialog not doing this?
+    if ( KIO::NetAccess::exists( url2, false, this ) )
     {
         if(KMessageBox::warningContinueCancel(this,QString("<qt>%1</qt>").arg(i18n("The file %1 already exists. "
-	            "Do you want to overwrite it?").arg(url.prettyURL())),i18n("Warning"),i18n("&Overwrite"))==KMessageBox::Cancel)
+	            "Do you want to overwrite it?").arg(url2.prettyURL())),i18n("Warning"),i18n("&Overwrite"))==KMessageBox::Cancel)
 	{
 	    return;
 	}
     }
 
-    QString filename;
-    if( url.isLocalFile() ) filename=url.path(0);
-    else filename=kapp->tempSaveName( url.path(0) );
+#if KDE_IS_VERSION( 3, 4, 92 )
+    // Support for partially remote KIO slave like media:
+    const KURL url ( KIO::NetAccess::mostLocalURL( url2, this ) );
+#else
+    const KURL url ( url2 );
+#endif
+    kdDebug() << "Saving marks: " << url2.prettyURL() << " most-local: " << url.prettyURL() << endl;
+    
+    QFile* file = 0;
+    KTempFile* tempFile = 0;
+    QTextStream* stream = 0;
+    bool error = false;
 
-    bool error=false;
-
-    QFile f(filename);
-    if( f.open(IO_WriteOnly) )
+    const bool localFile = url.isLocalFile();
+    if ( localFile )
     {
-	QTextStream s( &f );
-	s << "[Markers]" << endl;
-	for( QStringList::const_iterator it = _markerList.begin(); it!=_markerList.end() ; ++it )
-	    s << (*it) << endl;
-	f.close();
+        // We have a local file
+        file = new QFile( url.path() );
+        if ( file->open (IO_WriteOnly) )
+        {
+            stream = new QTextStream( file );
+        }
+        else
+        {
+            error = true;
+        }
     }
     else
     {
-	error=true;
-        KMessageBox::error(this,
-	    i18n("An error occurred while trying to write to file:\n%1\n").arg(url.prettyURL()));
+        tempFile = new KTempFile();
+        tempFile->setAutoDelete(true);
+        stream = tempFile->textStream();
+        error = !stream;
     }
-
-    if( !error && !url.isLocalFile())
+    if ( !error )
     {
-	if( !KIO::NetAccess::upload( filename, url ) )
-	{
-    	    KMessageBox::error(this,
-		i18n("An error occurred while trying to upload the file:\n%1\n").arg(url.prettyURL()));
-	}
+        // ### TODO: try to get a better file format for KDE4 (XML?), one working with real relative paths (no / at start) and working with UTF-8
+        *stream << "[Markers]" << endl;
+        for( QStringList::const_iterator it = _markerList.constBegin(); it!=_markerList.constEnd() ; ++it )
+            *stream << (*it) << endl;
+    }
+    if ( error )
+    {
+        // ### KDE4 FIXME: strip the final \n of the message
+        KMessageBox::error( this,
+            i18n( "An error occurred while trying to write to file:\n%1\n" ).arg( url.prettyURL()) );
+    }
+    else if ( !localFile )
+    {
+        tempFile->close();
+        if( !KIO::NetAccess::upload( tempFile->name(), url, this ) )
+        {
+            // ### KDE4 FIXME: strip the final \n of the message
+            KMessageBox::error(this,
+                i18n("An error occurred while trying to upload the file:\n%1\n").arg(url.prettyURL()));
+        }
     }
 
-    if( !url.isLocalFile() ) QFile::remove(filename);
-
-   checkSelected();
+    // We have finished so clean up
+    if ( localFile )
+    {
+        delete stream;
+        file->close();
+        delete file;
+    }
+    else
+    {
+        delete tempFile;
+    }
+   
+    checkSelected();
 }
 
 void CatalogManagerView::slotMarkPattern( )
@@ -590,7 +628,7 @@ void CatalogManagerView::setPatternMarks(bool mark)
   rx.setCaseSensitive(markPatternDialog->isCaseSensitive( ));
 
   QStringList fileList = item->allChildrenList(true);
-  for (QStringList::const_iterator it = fileList.begin( ); it != fileList.end( ); ++it) {
+  for (QStringList::const_iterator it = fileList.constBegin( ); it != fileList.constEnd( ); ++it) {
     CatManListItem * i = _fileList[*it];
 
     QString matchName;
@@ -667,7 +705,7 @@ void CatalogManagerView::markedStatistics()
 
    QStringList markedDoList;
    QStringList::const_iterator it;
-   for( it = doList.begin(); it != doList.end(); ++it )
+   for( it = doList.constBegin(); it != doList.constEnd(); ++it )
    {
          CatManListItem* item = _fileList[(*it)];
 	 if( item->marked() ) markedDoList.append(item->package());
@@ -690,7 +728,7 @@ void CatalogManagerView::showStatistics( CatManListItem  *i, QStringList &childr
       int totalUntranslated=0;
 
       QStringList::const_iterator it;
-      for( it = childrenList.begin(); it != childrenList.end(); ++it )
+      for( it = childrenList.constBegin(); it != childrenList.constEnd(); ++it )
       {
          CatManListItem* item = _fileList[(*it)];
 
@@ -800,12 +838,12 @@ void CatalogManagerView::checkSyntax()
          }
          case Msgfmt::NoExecutable:
          {
-            KMessageBox::sorry(this,i18n("Can not execute msgfmt. Please make sure you have msgfmt in your PATH!"));
+            KMessageBox::sorry(this,i18n("Cannot execute msgfmt. Please make sure that you have msgfmt in your PATH."));
             break;
          }
 	 case Msgfmt::Unsupported:
 	 {
-    	    KMessageBox::sorry(this,i18n("You can use gettext tools only for checking GNU PO files."));
+    	    KMessageBox::sorry(this,i18n("You can use gettext tools only for checking PO files."));
 	    break;
 	 }
       }
@@ -889,12 +927,12 @@ void CatalogManagerView::checkSyntax()
          }
          case Msgfmt::NoExecutable:
          {
-            KMessageBox::sorry(this,i18n("Cannot execute msgfmt. Please make sure you have msgfmt in your PATH."));
+            KMessageBox::sorry(this,i18n("Cannot execute msgfmt. Please make sure that you have msgfmt in your PATH."));
             break;
          }
 	 case Msgfmt::Unsupported:
 	 {
-    	    KMessageBox::sorry(this,i18n("You can use gettext tools only for checking GNU PO files."));
+    	    KMessageBox::sorry(this,i18n("You can use gettext tools only for checking PO files."));
 	    break;
 	 }
       }
@@ -909,7 +947,7 @@ void CatalogManagerView::roughTranslation()
     {
 	QStringList s = current->allChildrenList(true);
 	QStringList::const_iterator it;
-	for( it = s.begin() ; it != s.end(); ++it )
+	for( it = s.constBegin() ; it != s.constEnd(); ++it )
 	{
 	    CatManListItem *item = _fileList[(*it)];
 	    if( item ) result.append( item );
@@ -932,7 +970,7 @@ void CatalogManagerView::markedRoughTranslation()
     QPtrList<CatManListItem> result;
 
     QStringList::const_iterator it;
-    for( it = _markerList.begin() ; it != _markerList.end(); ++it )
+    for( it = _markerList.constBegin() ; it != _markerList.constEnd(); ++it )
     {
 	CatManListItem *item = _fileList[(*it)];
 	result.append( item );
@@ -951,7 +989,7 @@ void CatalogManagerView::mailFiles()
     QStringList childrenList = item->allChildrenList(true);
 
     QStringList::const_iterator it;
-    for (it = childrenList.begin(); it != childrenList.end(); ++it) {
+    for (it = childrenList.constBegin(); it != childrenList.constEnd(); ++it) {
       CatManListItem* i = _fileList[(*it)];
       if (i->hasPo()) {
 	filesToSend << i->poFile();
@@ -972,7 +1010,7 @@ void CatalogManagerView::mailMarkedFiles()
 
   QStringList filesToSend;
   QStringList::const_iterator it;
-  for (it = _markerList.begin(); it != _markerList.end(); ++it) {
+  for (it = _markerList.constBegin(); it != _markerList.constEnd(); ++it) {
     CatManListItem* i = _fileList[(*it)];
     if (i->hasPo()) {
       filesToSend << i->poFile();
@@ -989,7 +1027,7 @@ void CatalogManagerView::packageFiles( )
         QStringList childrenList = item->allChildrenList(true);
 
         QStringList::const_iterator it;
-        for (it = childrenList.begin(); it != childrenList.end(); ++it) {
+        for (it = childrenList.constBegin(); it != childrenList.constEnd(); ++it) {
           CatManListItem* i = _fileList[(*it)];
           if (i->hasPo()) {
 	    filesToPackage << i->poFile();
@@ -1013,7 +1051,7 @@ void CatalogManagerView::packageMarkedFiles( )
 
     QStringList filesToPackage;
     QStringList::const_iterator it;
-    for (it = _markerList.begin(); it != _markerList.end(); ++it) {
+    for (it = _markerList.constBegin(); it != _markerList.constEnd(); ++it) {
       CatManListItem* i = _fileList[(*it)];
       if (i->hasPo()) {
         filesToPackage << i->poFile();
@@ -1086,7 +1124,7 @@ void CatalogManagerView::doCVSCommand( CVS::Command cmd, bool marked, bool templ
     if ( _markerList.count( ) == 0 ) return;
     QStringList fileList;
     QStringList::const_iterator it;
-    for ( it = _markerList.begin( ); it != _markerList.end( ); ++it ) {
+    for ( it = _markerList.constBegin( ); it != _markerList.constEnd( ); ++it ) {
       CatManListItem * i = _fileList[(*it)];
       if ( templates && i->hasPot( ) )
         fileList << i->potFile( );
@@ -1197,7 +1235,7 @@ void CatalogManagerView::doSVNCommand( SVN::Command cmd, bool marked, bool templ
         if ( _markerList.count( ) == 0 ) return;
         QStringList fileList;
         QStringList::const_iterator it;
-        for ( it = _markerList.begin( ); it != _markerList.end( ); ++it ) {
+        for ( it = _markerList.constBegin( ); it != _markerList.constEnd( ); ++it ) {
             CatManListItem * i = _fileList[(*it)];
             if ( templates && i->hasPot( ) )
                 fileList << i->potFile( );
@@ -1251,7 +1289,7 @@ QString CatalogManagerView::find( FindOptions &options, QStringList &rest )
    emit prepareFindProgressBar(childrenList.size());
 
    QStringList::const_iterator it;
-   for( it = childrenList.begin(); it != childrenList.end(); ++it )
+   for( it = childrenList.constBegin(); it != childrenList.constEnd(); ++it )
    {
 	 CatManListItem* item = _fileList[(*it)];
 
@@ -1302,7 +1340,7 @@ QString CatalogManagerView::find( FindOptions &options, QStringList &rest )
 		const QString foundItemFile = itemFile;
 
 		it++;
-		while( it != childrenList.end() )
+		while( it != childrenList.constEnd() )
 		{
         	    CatManListItem *item = _fileList[(*it)];
 
@@ -1350,8 +1388,8 @@ QString CatalogManagerView::find( FindOptions &options, QStringList &rest )
 
 bool CatalogManagerView::hasMatchingWords( QStringList &itemWords, QStringList &searchWords)
 {
-    for( QStringList::const_iterator it1 = searchWords.begin() ; it1 != searchWords.end() ; ++it1 )
-	for( QStringList::const_iterator it2 = itemWords.begin() ; it2 != itemWords.end() ; ++it2 )
+    for( QStringList::const_iterator it1 = searchWords.constBegin() ; it1 != searchWords.constEnd() ; ++it1 )
+	for( QStringList::const_iterator it2 = itemWords.constBegin() ; it2 != itemWords.constEnd() ; ++it2 )
 	    if( *it1 == *it2
 		|| (*it1).contains(*it2)
 		|| (*it2).contains(*it1) ) return true;
@@ -1510,7 +1548,7 @@ void CatalogManagerView::slotToggleMarksInDir()
       const QStringList contentList = i->allChildrenList(true);
 
       QStringList::const_iterator it;
-      for( it = contentList.begin(); it != contentList.end(); ++it )
+      for( it = contentList.constBegin(); it != contentList.constEnd(); ++it )
       {
          CatManListItem* item = _fileList[(*it)];
 
@@ -1544,7 +1582,7 @@ void CatalogManagerView::slotClearMarksInDir()
       const QStringList contentList=i->contentsList(true);
 
       QStringList::const_iterator it;
-      for( it = contentList.begin(); it != contentList.end(); ++it )
+      for( it = contentList.constBegin(); it != contentList.constEnd(); ++it )
       {
          CatManListItem* item = _fileList[(*it)];
 
@@ -1884,7 +1922,7 @@ bool CatalogManagerView::buildDir(const QString& baseDir,const QString& relDir
 
       QStringList::const_iterator it;
 
-      for (  it = entryList.begin(); it != entryList.end() && !_stop ; ++it )
+      for (  it = entryList.constBegin(); it != entryList.constEnd() && !_stop ; ++it )
       {
 	  if( _stop ) return false;
 
@@ -1913,7 +1951,7 @@ bool CatalogManagerView::buildDir(const QString& baseDir,const QString& relDir
 
       entryList=dir.entryList(QDir::Dirs,QDir::Name);
 
-      for (  it = entryList.begin(); it != entryList.end() && !_stop ; ++it )
+      for (  it = entryList.constBegin(); it != entryList.constEnd() && !_stop ; ++it )
       {
           kapp->processEvents(100);
 
@@ -1985,7 +2023,7 @@ void CatalogManagerView::updateDir(QString relDir)
 
       QStringList::const_iterator it;
 
-      for (  it = entryList.begin(); it != entryList.end(); ++it )
+      for (  it = entryList.constBegin(); it != entryList.constEnd(); ++it )
       {
           if( _stop ) return;
 
@@ -2016,7 +2054,7 @@ void CatalogManagerView::updateDir(QString relDir)
 
       entryList=dir.entryList(QDir::Dirs,QDir::Name);
 
-      for (  it = entryList.begin(); it != entryList.end(); ++it )
+      for (  it = entryList.constBegin(); it != entryList.constEnd(); ++it )
       {
           kapp->processEvents(100);
 
@@ -2069,7 +2107,7 @@ void CatalogManagerView::updateDir(QString relDir)
       dir.setPath(poBaseDir+relDir);
       entryList=dir.entryList("*.po",QDir::Files,QDir::Name);
 
-      for (  it = entryList.begin(); it != entryList.end(); ++it )
+      for (  it = entryList.constBegin(); it != entryList.constEnd(); ++it )
       {
           havePoFiles=true;
 
@@ -2100,7 +2138,7 @@ void CatalogManagerView::updateDir(QString relDir)
 
       entryList=dir.entryList(QDir::Dirs,QDir::Name);
 
-      for (  it = entryList.begin(); it != entryList.end(); ++it )
+      for (  it = entryList.constBegin(); it != entryList.constEnd(); ++it )
       {
           kapp->processEvents(100);
 
@@ -2157,7 +2195,7 @@ void CatalogManagerView::updateDir(QString relDir)
       if(contentList.count()>0)
       {
           QStringList::const_iterator it;
-          for( it = contentList.begin(); it != contentList.end(); ++it )
+          for( it = contentList.constBegin(); it != contentList.constEnd(); ++it )
           {
              QFileInfo po(poBaseDir+(*it));
              QFileInfo pot(potBaseDir+(*it));
@@ -2354,7 +2392,7 @@ void CatalogManagerView::directoryDeleted(const QString& dir)
 
          CatManListItem* item;
          QStringList::const_iterator it;
-         for( it = childList.begin();it !=  childList.end(); ++it )
+         for( it = childList.constBegin();it !=  childList.constEnd(); ++it )
          {
             item=_fileList[(*it)];
             if(item)
@@ -2417,8 +2455,8 @@ void CatalogManagerView::setSettings(CatManSettings newSettings)
 
    _dirCommandsMenu->clear();
    int counter=0;
-   for ( QStringList::const_iterator it = _settings.dirCommandNames.begin()
-                        ; it != _settings.dirCommandNames.end(); ++it )
+   for ( QStringList::const_iterator it = _settings.dirCommandNames.constBegin()
+                        ; it != _settings.dirCommandNames.constEnd(); ++it )
    {
       _dirCommandsMenu->insertItem((*it),counter);
       counter++;
@@ -2428,8 +2466,8 @@ void CatalogManagerView::setSettings(CatManSettings newSettings)
 
    _fileCommandsMenu->clear();
    counter=0;
-   for ( QStringList::const_iterator it = _settings.fileCommandNames.begin()
-                        ; it != _settings.fileCommandNames.end(); ++it )
+   for ( QStringList::const_iterator it = _settings.fileCommandNames.constBegin()
+                        ; it != _settings.fileCommandNames.constEnd(); ++it )
    {
       _fileCommandsMenu->insertItem((*it),counter);
       counter++;
@@ -2560,7 +2598,7 @@ void CatalogManagerView::deleteDirItem(QString relDir)
 	QStringList childList = thisItem->allChildrenList();
 
 	QStringList::const_iterator it;
-	for( it = childList.begin();it !=  childList.end(); ++it )
+	for( it = childList.constBegin();it !=  childList.constEnd(); ++it )
     {
 		if(!_fileList.remove((*it)))
 			_dirList.remove((*it));
@@ -2866,7 +2904,7 @@ QStringList CatalogManagerView::current()
     {
 	QStringList s = current->allChildrenList(true);
 	QStringList::const_iterator it;
-	for( it = s.begin() ; it != s.end(); ++it )
+	for( it = s.constBegin() ; it != s.constEnd(); ++it )
 	{
 	    CatManListItem *item = _fileList[(*it)];
 	    result.append( item->poFile() );
@@ -2884,7 +2922,7 @@ QStringList CatalogManagerView::marked()
     QStringList result;
 
     QStringList::const_iterator it;
-    for( it = _markerList.begin() ; it != _markerList.end(); ++it )
+    for( it = _markerList.constBegin() ; it != _markerList.constEnd(); ++it )
     {
 	CatManListItem *item = _fileList[(*it)];
 	result.append( item->poFile() );
@@ -2926,7 +2964,7 @@ void CatalogManagerView::updateCurrent()
 void CatalogManagerView::updateFiles( const QStringList& files )
 {
   QStringList::ConstIterator it;
-  for ( it = files.begin( ); it != files.end( ); ++it ) {
+  for ( it = files.constBegin( ); it != files.constEnd( ); ++it ) {
     updateFile( *it, true );
   }
 }
@@ -2949,7 +2987,7 @@ void CatalogManagerView::validateUsingTool( const KDataToolInfo &tool, const QSt
     {
 	const QStringList s = current->allChildrenList(true);
 	QStringList::const_iterator it;
-	for( it = s.begin() ; it != s.end(); ++it )
+	for( it = s.constBegin() ; it != s.constEnd(); ++it )
 	{
 	    CatManListItem *item = _fileList[(*it)];
 	    if( item && item->hasPo() ) result.append( item->package() );
@@ -2976,8 +3014,8 @@ void CatalogManagerView::validate_internal( const QStringList& files, const KDat
 
     if( !t )
     {
-	KMessageBox::error( this, i18n("Can not instantiate a validation tool.\n"
-	"Please, check your installation."), i18n("Validation Tool Error") );
+	KMessageBox::error( this, i18n("Cannot instantiate a validation tool.\n"
+	"Please check your installation."), i18n("Validation Tool Error") );
 	return;
     }
 
@@ -3046,7 +3084,7 @@ void CatalogManagerView::updateMarkerList()
 {
     QStringList newMarkers;
 
-    for( QStringList::const_iterator it = _markerList.begin(); it != _markerList.end(); ++it ) {
+    for( QStringList::const_iterator it = _markerList.constBegin(); it != _markerList.constEnd(); ++it ) {
         if( _fileList[ (*it) ] )
 	    newMarkers.append( (*it) );
     }
