@@ -15,7 +15,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
@@ -43,6 +43,7 @@
 // Forwarding Qt classes
 class QString;
 class QStringList;
+class QWidget;
 
 /**
  * This class is the backend for CVS support in Catalog Manager.
@@ -70,22 +71,27 @@ class CVSHandler : public QObject
     void setPOBaseDir( const QString& dir );
     void setPOTBaseDir( const QString& dir );
 
-    FileStatus fstatus( const QString& filename );
-    QString fileStatus( const QString& filename );
+    FileStatus fstatus( const QString& filename ) const;
+    QString fileStatus( const FileStatus status ) const;
     QString cvsStatus( const QString& filename ) const;
 
-    void execCVSCommand(CVS::Command cmd, const QString& filename, bool templates = false);
-    void execCVSCommand(CVS::Command cmd, const QStringList& files, bool templates = false);
+    void execCVSCommand( QWidget* parent, CVS::Command cmd, const QString& filename, bool templates = false );
+    void execCVSCommand( QWidget* parent, CVS::Command cmd, const QStringList& files, bool templates = false );
 
     void setAutoUpdateTemplates( bool update );
 
+    /**
+     * True if the file was modified or has another status considered as a modification
+     */
+    bool isConsideredModified( const FileStatus status ) const;
+
   signals:
     void signalIsPORepository( bool );
     void signalIsPOTRepository( bool );
     void signalFilesCommitted( const QStringList& );
 
   private:
-    void showDialog( CVS::Command cmd, const QStringList& files, const QString& commandLine );
+    void showDialog( QWidget* parent, CVS::Command cmd, const QStringList& files, const QString& commandLine );
     void checkToAdd( const QStringList& files );
     void processStatusOutput( const QString& status );
     void processDiff( QString output );
