@@ -833,20 +833,18 @@ QString Catalog::packageName() const
 
 void Catalog::setPackage(const QString& package )
 {
-    int pos=package.findRev("/");
-    if( pos<0 )
+    const int pos = package.findRev( '/' );
+    if( pos < 0 )
     {
-	d->_packageDir = "";
+	d->_packageDir = QString();
 	d->_packageName = package;
-	d->_packageName.replace( QRegExp("^/+"),"");
     }
     else
     {
-	d->_packageDir = package.left(pos);
-	if( !d->_packageDir.endsWith("/") ) d->_packageDir+="/";
-	d->_packageName = package.right(package.length()-pos);
-	d->_packageName.replace( QRegExp("^/+"),"");
+	d->_packageDir = package.left( pos + 1 ); // We want the / included
+	d->_packageName = package.mid( pos + 1 ); // We do not want /
     }
+    kdDebug() << k_funcinfo << " " << package << " => " << d->_packageDir << " + " << d->_packageName << endl;
 }
 
 QString Catalog::packageDir() const
