@@ -187,8 +187,9 @@ public:
    *
    * @param index  index of the requested message
    * @return       context information found in the message comment
+   * @deprecated
    */
-   QString context(uint index) const;
+   QString context(uint index) const KDE_DEPRECATED;
 
    /**
    * Get the header for the current file.
