@@ -76,7 +76,7 @@ QString CatalogItem::msgctxt(const bool noNewlines) const
     if( noNewlines )
     {
         QString tmp = d->_msgctxt;
-        tmp.replace("\n", " ");
+        tmp.replace("\n", " "); // ### TODO: " " or "" ?
         return tmp;
     }
     else
@@ -88,14 +88,7 @@ QStringList CatalogItem::msgid(const bool noNewlines) const
     QStringList result=d->_msgid;
     if( noNewlines )
     {
-        // ### TODO JJ: use QstringList::gres to replace inside the QStringLisz
-        result.clear();
-        for( QStringList::Iterator it = d->_msgid.begin() ; it != d->_msgid.end() ; it++ )
-	{
-	    QString resultstring = (*it);
-	    resultstring.replace("\n","");
-	    result.append(resultstring);
-	}
+        result.gres( "\n", "" );
     }
     return result;
 }
@@ -105,14 +98,7 @@ QStringList CatalogItem::msgstr(const bool noNewlines) const
     QStringList result=d->_msgstr;
     if( noNewlines )
     {
-        // ### TODO JJ: use QstringList::gres to replace inside the QStringLisz
-	result.clear();
-	for( QStringList::Iterator it = d->_msgstr.begin() ; it != d->_msgstr.end() ; it++ )
-	{
-	    QString resultstring = (*it);
-	    resultstring.replace("\n","");
-	    result.append(resultstring);
-	}
+        result.gres( "\n", "" );
     }
     return result;
 }
@@ -255,7 +241,7 @@ bool CatalogItem::isUntranslated() const
 PluralFormType CatalogItem::pluralForm() const
 {
     if( d->_gettextPluralForm ) return Gettext;
-    if( d->_msgid.first().find( QRegExp("_n:\\s")) == 0 ) return KDESpecific;
+    if( d->_msgid.first().find( QRegExp("_n:\\s")) == 0 ) return KDESpecific; // ### TODO: we could use startsWith("_n: ")
     else return NoPluralForm;
 }
 
@@ -528,3 +514,5 @@ void CatalogItem::setProject( Project::Ptr project )
 {
     d->_project = project;
 }
+
+// kate: space-indent on; indent-width 4; replace-tabs on;
