@@ -1,3 +1,5 @@
+// kate: space-indent on; indent-width 3; replace-tabs on;
+
 /* ****************************************************************************
   This file is part of KBabel
 
@@ -18,7 +20,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
@@ -58,8 +60,10 @@ GettextImportPlugin::GettextImportPlugin(QObject* parent, const char* name, cons
 
 ConversionStatus GettextImportPlugin::load(const QString& filename, const QString&)
 {
-   if ( filename.isEmpty() )
-    kdDebug(KBABEL) << "fatal error: empty filename to open" << endl;
+   if ( filename.isEmpty() ) {
+      kdDebug(KBABEL) << "fatal error: empty filename to open" << endl;
+      return NO_FILE;
+   }
 
    QFileInfo info(filename);
 
@@ -73,127 +77,129 @@ ConversionStatus GettextImportPlugin::load(const QString& filename, const QStrin
 
 
    bool recoveredError=false;
-   bool docbookContent=false;
    bool docbookFile=false;
    	
-   if(file.open(IO_ReadOnly))
+   if ( !file.open( IO_ReadOnly ) )
+      return NO_PERMISSIONS;
+   
+   uint oldPercent = 0;
+   emit signalResetProgressBar(i18n("loading file"),100);
+
+   QByteArray ba = file.readAll();
+   file.close();
+
+   // find codec for file
+   bool hadCodec;
+   QTextCodec* codec=codecForArray( ba, &hadCodec );
+   
+   QTextStream stream(ba,IO_ReadOnly);
+   if(codec)
+      stream.setCodec(codec);
+   QIODevice *dev = stream.device();
+   int fileSize = dev->size();
+
+   // if somethings goes wrong with the parsing, we don't have deleted the old contents
+   CatalogItem tempHeader;
+   QStringList tempObsolete;
+
+
+   kdDebug(KBABEL) << "start parsing..." << endl;
+
+   // first read header
+   ConversionStatus status = readHeader(stream);
+
+   if(status!=OK)
    {
-      uint oldPercent = 0;
-      emit signalResetProgressBar(i18n("loading file"),100);
-      
-      QByteArray ba = file.readAll();
-      
-      // find codec for file
-	  bool hadCodec;
-      QTextCodec* codec=codecForFile(file,&hadCodec);
-
-      file.close();
-
-      QTextStream stream(ba,IO_ReadOnly);
-      if(codec)
-          stream.setCodec(codec);
-      QIODevice *dev = stream.device();
-	  int fileSize = dev->size();
-
-      // if somethings goes wrong with the parsing, we don't have deleted the old contents
-      CatalogItem tempHeader;
-      QStringList tempObsolete;
-
-
-      kdDebug(KBABEL) << "start parsing..." << endl;
-
-      // first read header
-      ConversionStatus status = readHeader(stream);
-      
-      if(status!=OK)
-      {
-          emit signalClearProgressBar();
-	  
-	  if( status == RECOVERED_PARSE_ERROR ) status = HEADER_ERROR;
-
-          return status;
-      }
-      
-      tempHeader.setMsgid( _msgid );
-      tempHeader.setMsgstr( _msgstr );
-      tempHeader.setComment( _comment );
-      if(tempHeader.isFuzzy())
-      {
-    	     tempHeader.removeFuzzy();
-      }
-
-      // check if header seems to indicate docbook content generated by xml2pot
-      docbookContent = tempHeader.msgstr().contains("application/x-xml2pot");
-
-      // now parse the rest of the file
-      ConversionStatus success=OK;
-      uint counter=0;
-      QValueList<uint> errorIndex;
-
-      while(!stream.eof() && success==OK )
-      {
-         kapp->processEvents(10);
-	 if( isStopped() )
-	 {
-	    return STOPPED;
-	 }
-
-         success=readEntry(stream);
-
-         if(success==OK)
-         {
-	    if( _obsolete )
-	    {
-		success=OK;
-		tempObsolete.append(_comment);
-	    }
-	    else 
-	    {
-		CatalogItem tempCatItem;
-		tempCatItem.setMsgid( _msgid );
-		tempCatItem.setMsgstr( _msgstr );
-		tempCatItem.setComment( _comment );
-		tempCatItem.setGettextPluralForm( _gettextPluralForm );
-		
-        	// add new entry to the list of entries
-        	appendCatalogItem(tempCatItem);
-        	// check if first comment seems to indicate a docbook source file
-        	if(counter==0)
-            	    docbookFile = tempCatItem.comment().contains(".docbook");
-	    }
-         }
-         else if(success==RECOVERED_PARSE_ERROR)
-         {
-            success=OK;
-            recoveredError=true;
-            errorIndex.append(counter);
-	    
-	    CatalogItem tempCatItem;
-	    tempCatItem.setMsgid( _msgid );
-	    tempCatItem.setMsgstr( _msgstr );
-	    tempCatItem.setComment( _comment );
-	    tempCatItem.setGettextPluralForm( _gettextPluralForm );
-
-            // add new entry to the list of entries
-            appendCatalogItem(tempCatItem);
-         }	 
-	 counter++;
-
-         if((100*dev->at())/fileSize > oldPercent)
-	 {
-	    oldPercent = (100*dev->at())/fileSize;
-	    emit signalProgress(oldPercent);
-	 }
-      }
-
-
-      // to be sure it is set to 100, if someone don't connect to
-      // signalClearProgressBar()
-      emit signalProgress(100);
-
       emit signalClearProgressBar();
 
-      kdDebug(KBABEL) << "ready." << endl;
+      if( status == RECOVERED_PARSE_ERROR ) status = HEADER_ERROR;
+
+      return status;
+   }
+
+   tempHeader.setMsgid( _msgid );
+   tempHeader.setMsgstr( _msgstr );
+   tempHeader.setComment( _comment );
+   if(tempHeader.isFuzzy())
+   {
+      tempHeader.removeFuzzy();
+   }
+
+   // check if header seems to indicate docbook content generated by xml2pot
+   const bool docbookContent = (tempHeader.msgstr().find("application/x-xml2pot") != tempHeader.msgstr().end());
+
+   // now parse the rest of the file
+   ConversionStatus success=OK;
+   uint counter=0;
+   QValueList<uint> errorIndex;
+
+   while(!stream.eof() && success==OK )
+   {
+      kapp->processEvents(10);
+      if( isStopped() )
+      {
+         return STOPPED;
+      }
+
+      success=readEntry(stream);
+
+      if(success==OK)
+      {
+         if( _obsolete )
+         {
+               success=OK;
+               tempObsolete.append(_comment);
+         }
+         else
+         {
+               CatalogItem tempCatItem;
+               tempCatItem.setMsgctxt( _msgctxt );
+               tempCatItem.setMsgid( _msgid );
+               tempCatItem.setMsgstr( _msgstr );
+               tempCatItem.setComment( _comment );
+               tempCatItem.setGettextPluralForm( _gettextPluralForm );
+               
+               // add new entry to the list of entries
+               appendCatalogItem(tempCatItem);
+               // check if first comment seems to indicate a docbook source file
+               if(counter==0)
+                  docbookFile = ( tempCatItem.comment().find(".docbook") != -1 );
+         }
+      }
+      else if(success==RECOVERED_PARSE_ERROR)
+      {
+         success=OK;
+         recoveredError=true;
+         errorIndex.append(counter);
+         
+         CatalogItem tempCatItem;
+         tempCatItem.setMsgctxt( _msgctxt );
+         tempCatItem.setMsgid( _msgid );
+         tempCatItem.setMsgstr( _msgstr );
+         tempCatItem.setComment( _comment );
+         tempCatItem.setGettextPluralForm( _gettextPluralForm );
+
+         // add new entry to the list of entries
+         appendCatalogItem(tempCatItem);
+      }
+      counter++;
+
+      const uint newPercent = (100*dev->at())/fileSize;
+      if(newPercent > oldPercent)
+      {
+         oldPercent = newPercent;
+         emit signalProgress(oldPercent);
+      }
+   }
+
+
+   // to be sure it is set to 100, if someone don't connect to
+   // signalClearProgressBar()
+   emit signalProgress(100);
+
+   emit signalClearProgressBar();
+
+   kdDebug(KBABEL) << "ready." << endl;
       
       if(counter==0)
       {
@@ -201,27 +207,22 @@ ConversionStatus GettextImportPlugin::load(const QString& filename, const QStrin
 	return PARSE_ERROR;
       }
 
-      if(success!=PARSE_ERROR)
-      {
-         setGeneratedFromDocbook(docbookContent || docbookFile);
+   if(success!=PARSE_ERROR)
+   {
+      setGeneratedFromDocbook(docbookContent || docbookFile);
 
-         setHeader(tempHeader);
-	 setCatalogExtraData(tempObsolete);
-         setErrorIndex(errorIndex);
+      setHeader(tempHeader);
+      setCatalogExtraData(tempObsolete);
+      setErrorIndex(errorIndex);
 
-         if(hadCodec)
-            setFileCodec(codec);
-         else
-            setFileCodec(0);
-      }
+      if(hadCodec)
+         setFileCodec(codec);
       else
-      {
-         return PARSE_ERROR;
-      }
+         setFileCodec(0);
    }
    else
    {
-      return NO_PERMISSIONS;
+      return PARSE_ERROR;
    }
    
    setMimeTypes( "application/x-gettext" );
@@ -232,64 +233,37 @@ ConversionStatus GettextImportPlugin::load(const QString& filename, const QStrin
    return OK;
 }
 
-QTextCodec* GettextImportPlugin::codecForFile(QFile& file, bool* hadCodec)
+QTextCodec* GettextImportPlugin::codecForArray(QByteArray& array, bool* hadCodec)
 {
-   bool wasOpen=true;
-   int fileIndex=0;
-   
    if(hadCodec)
    {
       *hadCodec=false;
    }
 
-   if(!file.isOpen())
-   {
-      wasOpen=false;
-
-      if(!file.open(IO_ReadOnly))
-      {
-         kdDebug(KBABEL) << "wasn't able to open file" << endl;
-         return 0;
-      }
-   }
-   else
-   {
-      fileIndex=file.at();
-		file.at(0);
-   }
-
-   QTextStream stream(&file);
+   QTextStream stream( array, IO_ReadOnly );
+   // If needed this will detect a UTF-16 BOM (Byte Order mark), otherwise we assume that the header is in ASCII.
+   stream.setEncoding( QTextStream::UnicodeUTF8 );
+   // ### Qt4: set encoding to UTF-8 and set Unicode auto-detection
 
    // first read header
    ConversionStatus status = readHeader(stream);
    if(status!=OK && status != RECOVERED_PARSE_ERROR)
    {
        kdDebug(KBABEL) << "wasn't able to read header" << endl;
-       if(!wasOpen)
-          file.close();
        return 0;
    }
 
-   QString charset;
+   const QString head = _msgstr.first();
 
-   QString head = _msgstr.first();
-
-   QRegExp r("Content-Type:\\s*\\w+/[-\\w]+;\\s*charset\\s*=\\s*[^\\\"\\n]+");
-   int begin=r.search(head);
-   int len=r.matchedLength();
-   if(begin<0) {
-   	kdDebug(KBABEL) << "no charset entry found" << endl;
-   	return 0;
-   }	
-   	
-   head = head.mid(begin,len);
-
-   QRegExp regexp("charset *= *([^\\\\\\\"]+)");
-   if( regexp.search( head ) > -1 )
+   QRegExp regexp("Content-Type:\\s*\\w+/[-\\w]+;?\\s*charset\\s*=\\s*(\\S+)\\s*\\\\n");
+   if( regexp.search( head ) == -1 )
    {
-       charset = regexp.cap(1);
-       kdDebug(KBABEL) << QString("charset: ")+charset << " for " << file.name() << endl;
+      kdDebug(KBABEL) << "no charset entry found" << endl;
+      return 0;
    }
+   
+   const QString charset = regexp.cap(1);
+   kdDebug(KBABEL) << "charset: " << charset << endl;
 
    QTextCodec* codec=0;
 
@@ -305,7 +279,7 @@ QTextCodec* GettextImportPlugin::codecForFile(QFile& file, bool* hadCodec)
 
           codec=QTextCodec::codecForName("utf8");
           kdDebug(KBABEL) 
-              << QString("file seems to be a template: using utf8 encoding.")
+              << QString("file seems to be a template: using utf-8 encoding.")
               << endl;
       }
       else
@@ -317,19 +291,17 @@ QTextCodec* GettextImportPlugin::codecForFile(QFile& file, bool* hadCodec)
 
       if(!codec)
       {
-         kdWarning() << "charset found, but no codec available, using UTF8 instead" << endl;
+         kdWarning(KBABEL) << "charset found, but no codec available, using UTF-8 instead" << endl;
 	 codec=QTextCodec::codecForName("utf8");
       }
    }
-
-   if(!wasOpen)
-   {
-       file.close();
-   }
    else
    {
-       file.at(fileIndex);
+      // No charset? So it is probably ASCII, therefore UTF-8
+      kdWarning(KBABEL) << "No charset defined! Assuming UTF-8!" << endl;
+      codec=QTextCodec::codecForName("utf8");
    }
+         
 
    return codec;
 }
@@ -356,17 +328,19 @@ ConversionStatus GettextImportPlugin::readHeader(QTextStream& stream)
 
 ConversionStatus GettextImportPlugin::readEntry(QTextStream& stream)
 {
-   enum {Begin,Comment,Msgid,Msgstr} part=Begin;
+   enum {Begin,Comment,Msgctxt,Msgid,Msgstr} part=Begin;
 
    QString line;
    bool cancelLoop=false;
    bool error=false;
    bool recoverableError=false;
+   bool seenMsgctxt=false;
    _msgstr.clear();
-   _msgstr.append("");
+   _msgstr.append(QString());
    _msgid.clear();
-   _msgid.append("");
-   _comment="";
+   _msgid.append(QString());
+   _msgctxt=QString();
+   _comment=QString();
    _gettextPluralForm=false;
    _obsolete=false;
    
@@ -374,13 +348,21 @@ ConversionStatus GettextImportPlugin::readEntry(QTextStream& stream)
    
    while(!stream.eof() && !cancelLoop)
    {
-       int pos=stream.device()->at();
+       const int pos=stream.device()->at();
 
        line=stream.readLine();
-       
-       if(line.isNull()) // file end
-		   break;
 
+       // ### Qt4: no need of a such a check
+       if(line.isNull()) // file end
+          break;
+       else if ( line.startsWith( "<<<<<<<" ) || line.startsWith( "=======" ) || line.startsWith( ">>>>>>>" ) )
+       {
+          // We have found a CVS/SVN conflict marker. Abort.
+          // (It cannot be any useful data of the PO file, as otheriwse the line would start with a quote)
+          kdError(KBABEL) << "CVS/SVN conflict marker found! Aborting!" << endl << line << endl;
+          return PARSE_ERROR;
+       }
+       
        // remove whitespaces from beginning and end of line
        line=line.stripWhiteSpace();
 
@@ -390,40 +372,50 @@ ConversionStatus GettextImportPlugin::readEntry(QTextStream& stream)
            if(line.isEmpty())
               continue;
 
-           if(line.contains(QRegExp("^#~")))
+           if(line.startsWith("#~"))
            {
               _obsolete=true;
 	      part=Comment;
 	      _comment=line;
            }
-           else if(line.contains(QRegExp("^#")))
+           else if(line.startsWith("#"))
            {
                part=Comment;
                _comment=line;
            }
-           else if(line.contains(QRegExp("^msgid\\s*\".*\"$")))
+           else if(line.find(QRegExp("^msgctxt\\s*\".*\"$")) != -1)
+           {
+               part=Msgctxt;
+
+               // remove quotes at beginning and the end of the lines
+               line.remove(QRegExp("^msgctxt\\s*\""));
+               line.remove(QRegExp("\"$"));
+               _msgctxt=line;
+               seenMsgctxt=true;
+           }
+           else if(line.find(QRegExp("^msgid\\s*\".*\"$")) != -1)
            {
                part=Msgid;
 
                // remove quotes at beginning and the end of the lines
-               line.replace(QRegExp("^msgid\\s*\""),"");
-               line.replace(QRegExp("\"$"),"");
+               line.remove(QRegExp("^msgid\\s*\""));
+               line.remove(QRegExp("\"$"));
 
                (*(_msgid).begin())=line;
            }
 		     // one of the quotation marks is missing
-           else if(line.contains(QRegExp("^msgid\\s*\"?.*\"?$")))
+           else if(line.find(QRegExp("^msgid\\s*\"?.*\"?$")) != -1)
            {
                part=Msgid;
 
                // remove quotes at beginning and the end of the lines
-               line.replace(QRegExp("^msgid\\s*\"?"),"");
-               line.replace(QRegExp("\"$"),"");
+               line.remove(QRegExp("^msgid\\s*\"?"));
+               line.remove(QRegExp("\"$"));
 
                (*(_msgid).begin())=line;
 
-			   if(!line.isEmpty())
-			       recoverableError=true;
+               if(!line.isEmpty())
+                  recoverableError=true;
            }
            else
            {
@@ -438,38 +430,48 @@ ConversionStatus GettextImportPlugin::readEntry(QTextStream& stream)
             if(line.isEmpty() && _obsolete ) return OK;
 	    if(line.isEmpty() )
 	       continue;
-            else if(line.contains(QRegExp("^#~")))
+            else if(line.startsWith("#~"))
             {
                _comment+=("\n"+line);
 	       _obsolete=true;
             }
-            else if(line.contains(QRegExp("^#")))
+            else if(line.startsWith("#"))
             {
                _comment+=("\n"+line);
             }
-            else if(line.contains(QRegExp("^msgid\\s*\".*\"$")))
+            else if(line.find(QRegExp("^msgctxt\\s*\".*\"$")) != -1)
+            {
+               part=Msgctxt;
+
+               // remove quotes at beginning and the end of the lines
+               line.remove(QRegExp("^msgctxt\\s*\""));
+               line.remove(QRegExp("\"$"));
+               _msgctxt=line;
+               seenMsgctxt=true;
+            }
+            else if(line.find(QRegExp("^msgid\\s*\".*\"$")) != -1)
             {
                part=Msgid;
 
                // remove quotes at beginning and the end of the lines
-               line.replace(QRegExp("^msgid\\s*\""),"");
-               line.replace(QRegExp("\"$"),"");
+               line.remove(QRegExp("^msgid\\s*\""));
+               line.remove(QRegExp("\"$"));
 
                (*(_msgid).begin())=line;
             }
-			// one of the quotation marks is missing
-			else if(line.contains(QRegExp("^msgid\\s*\"?.*\"?$")))
+            // one of the quotation marks is missing
+            else if(line.find(QRegExp("^msgid\\s*\"?.*\"?$")) != -1)
             {
                part=Msgid;
 
                // remove quotes at beginning and the end of the lines
-               line.replace(QRegExp("^msgid\\s*\"?"),"");
-               line.replace(QRegExp("\"$"),"");
+               line.remove(QRegExp("^msgid\\s*\"?"));
+               line.remove(QRegExp("\"$"));
 
                (*(_msgid).begin())=line;
 			   
-			   if(!line.isEmpty())
-			       recoverableError=true;
+               if(!line.isEmpty())
+                     recoverableError=true;
             }
             else
             {
@@ -479,15 +481,63 @@ ConversionStatus GettextImportPlugin::readEntry(QTextStream& stream)
                cancelLoop=true;
             }
         }
+        else if(part==Msgctxt)
+        {
+            if(line.isEmpty())
+               continue;
+            else if(line.find(QRegExp("^\".*\\n?\"$")) != -1)
+            {
+               // remove quotes at beginning and the end of the lines
+               line.remove(QRegExp("^\""));
+               line.remove(QRegExp("\"$"));
+               
+               // add Msgctxt line to item
+               if(_msgctxt.isEmpty())
+                  _msgctxt=line;
+               else
+                  _msgctxt+=("\n"+line);
+            }
+            else if(line.find(QRegExp("^msgid\\s*\".*\"$")) != -1)
+            {
+               part=Msgid;
+
+               // remove quotes at beginning and the end of the lines
+               line.remove(QRegExp("^msgid\\s*\""));
+               line.remove(QRegExp("\"$"));
+
+               (*(_msgid).begin())=line;
+            }
+            // one of the quotation marks is missing
+            else if(line.find(QRegExp("^msgid\\s*\"?.*\"?$")) != -1)
+            {
+               part=Msgid;
+
+               // remove quotes at beginning and the end of the lines
+               line.remove(QRegExp("^msgid\\s*\"?"));
+               line.remove(QRegExp("\"$"));
+
+               (*(_msgid).begin())=line;
+			   
+               if(!line.isEmpty())
+                     recoverableError=true;
+            }
+            else
+            {
+               kdDebug(KBABEL) << "no msgid found after a msgctxt while parsing: " << _msgctxt << endl;
+
+               error=true;
+               cancelLoop=true;
+            }
+        }
         else if(part==Msgid)
         {
             if(line.isEmpty())
                continue;
-            else if(line.contains(QRegExp("^\".*\\n?\"$")))
+            else if(line.find(QRegExp("^\".*\\n?\"$")) != -1)
             {
                // remove quotes at beginning and the end of the lines
-               line.replace(QRegExp("^\""),"");
-               line.replace(QRegExp("\"$"),"");
+               line.remove(QRegExp("^\""));
+               line.remove(QRegExp("\"$"));
 
                QStringList::Iterator it;
                if(_gettextPluralForm)
@@ -501,84 +551,84 @@ ConversionStatus GettextImportPlugin::readEntry(QTextStream& stream)
                else
                   (*it)+=("\n"+line);
             }
-            else if(line.contains(QRegExp("^msgid_plural\\s*\".*\"$")))
+            else if(line.find(QRegExp("^msgid_plural\\s*\".*\"$")) != -1)
             {
                part=Msgid;
                _gettextPluralForm = true;
 
                // remove quotes at beginning and the end of the lines
-               line.replace(QRegExp("^msgid_plural\\s*\""),"");
-               line.replace(QRegExp("\"$"),"");
+               line.remove(QRegExp("^msgid_plural\\s*\""));
+               line.remove(QRegExp("\"$"));
 
                _msgid.append(line);
             }
-			// one of the quotation marks is missing
-			else if(line.contains(QRegExp("^msgid_plural\\s*\"?.*\"?$")))
+            // one of the quotation marks is missing
+            else if(line.find(QRegExp("^msgid_plural\\s*\"?.*\"?$")) != -1)
             {
                part=Msgid;
                _gettextPluralForm = true;
 
                // remove quotes at beginning and the end of the lines
-               line.replace(QRegExp("^msgid_plural\\s*\"?"),"");
-               line.replace(QRegExp("\"$"),"");
+               line.remove(QRegExp("^msgid_plural\\s*\"?"));
+               line.remove(QRegExp("\"$"));
 
                _msgid.append(line);
 			   
                if(!line.isEmpty())
-			       recoverableError=true;
+                  recoverableError=true;
             }
            else if(!_gettextPluralForm 
-                   && line.contains(QRegExp("^msgstr\\s*\".*\\n?\"$")))
+                    && (line.find(QRegExp("^msgstr\\s*\".*\\n?\"$")) != -1))
             {
                part=Msgstr;
 
                // remove quotes at beginning and the end of the lines
-               line.replace(QRegExp("^msgstr\\s*\"?"),"");
-               line.replace(QRegExp("\"$"),"");
+               line.remove(QRegExp("^msgstr\\s*\"?"));
+               line.remove(QRegExp("\"$"));
 
                (*msgstrIt)=line;
             }
-			else if(!_gettextPluralForm
-                    && line.contains(QRegExp("^msgstr\\s*\"?.*\\n?\"?$")))
+            else if(!_gettextPluralForm
+                    && line.find(QRegExp("^msgstr\\s*\"?.*\\n?\"?$")) != -1)
             {
                part=Msgstr;
 
                // remove quotes at beginning and the end of the lines
-               line.replace(QRegExp("^msgstr\\s*\"?"),"");
-               line.replace(QRegExp("\"$"),"");
+               line.remove(QRegExp("^msgstr\\s*\"?"));
+               line.remove(QRegExp("\"$"));
 
                (*msgstrIt)=line;
 
-			   if(!line.isEmpty())
-			       recoverableError=true;
+               if(!line.isEmpty())
+                  recoverableError=true;
             }
             else if( _gettextPluralForm 
-                    && line.contains(QRegExp("^msgstr\\[0\\]\\s*\".*\\n?\"$")))
+                     && (line.find(QRegExp("^msgstr\\[0\\]\\s*\".*\\n?\"$")) != -1))
             {
                part=Msgstr;
 
                // remove quotes at beginning and the end of the lines
-               line.replace(QRegExp("^msgstr\\[0\\]\\s*\"?"),"");
-               line.replace(QRegExp("\"$"),"");
+               line.remove(QRegExp("^msgstr\\[0\\]\\s*\"?"));
+               line.remove(QRegExp("\"$"));
 
                (*msgstrIt)=line;
             }
-			else if( _gettextPluralForm 
-                    && line.contains(QRegExp("^msgstr\\[0\\]\\s*\"?.*\\n?\"?$")))
+            else if( _gettextPluralForm
+                     && (line.find(QRegExp("^msgstr\\[0\\]\\s*\"?.*\\n?\"?$")) != -1))
             {
                part=Msgstr;
 
                // remove quotes at beginning and the end of the lines
-               line.replace(QRegExp("^msgstr\\[0\\]\\s*\"?"),"");
-               line.replace(QRegExp("\"$"),"");
+               line.remove(QRegExp("^msgstr\\[0\\]\\s*\"?"));
+               line.remove(QRegExp("\"$"));
 
                (*msgstrIt)=line;
 
-			   if(!line.isEmpty())
-			       recoverableError=true;
+               if(!line.isEmpty())
+                  recoverableError=true;
             }
  
-            else if(line.contains(QRegExp("^#")) || line.contains(QRegExp("^msgid")))
+            else if(line.startsWith("#") || line.startsWith("msgid"))
             {
                kdDebug(KBABEL) << "no msgstr or msgid found after a msgid while parsing: " << _msgid.first() << endl;
 
@@ -586,13 +636,13 @@ ConversionStatus GettextImportPlugin::readEntry(QTextStream& stream)
                error=true;
             }
             // a line of the msgid with a missing quotation mark
-            else if(line.contains(QRegExp("^\"?.+\\n?\"?$")))
+            else if(line.find(QRegExp("^\"?.+\\n?\"?$")) != -1)
             {
                recoverableError=true;
 
                // remove quotes at beginning and the end of the lines
-               line.replace(QRegExp("^\""),"");
-               line.replace(QRegExp("\"$"),"");
+               line.remove(QRegExp("^\""));
+               line.remove(QRegExp("\"$"));
 
                QStringList::Iterator it;
                if( _gettextPluralForm )
@@ -619,11 +669,11 @@ ConversionStatus GettextImportPlugin::readEntry(QTextStream& stream)
             if(line.isEmpty())
                continue;
             // another line of the msgstr
-            else if(line.contains(QRegExp("^\".*\\n?\"$")))
+            else if(line.find(QRegExp("^\".*\\n?\"$")) != -1)
             {
                // remove quotes at beginning and the end of the lines
-               line.replace(QRegExp("^\""),"");
-               line.replace(QRegExp("\"$"),"");
+               line.remove(QRegExp("^\""));
+               line.remove(QRegExp("\"$"));
 
                if((*msgstrIt).isEmpty())
                   (*msgstrIt)=line;
@@ -631,33 +681,33 @@ ConversionStatus GettextImportPlugin::readEntry(QTextStream& stream)
                   (*msgstrIt)+=("\n"+line);
             }
             else if( _gettextPluralForm
-                    && line.contains(QRegExp("^msgstr\\[[0-9]+\\]\\s*\".*\\n?\"$")))
+                     && (line.find(QRegExp("^msgstr\\[[0-9]+\\]\\s*\".*\\n?\"$")) != -1))
             {
                // remove quotes at beginning and the end of the lines
-               line.replace(QRegExp("^msgstr\\[[0-9]+\\]\\s*\"?"),"");
-               line.replace(QRegExp("\"$"),"");
+               line.remove(QRegExp("^msgstr\\[[0-9]+\\]\\s*\"?"));
+               line.remove(QRegExp("\"$"));
 
                msgstrIt=_msgstr.append(line);
             }
 	    else if( _gettextPluralForm 
-                    && line.contains(QRegExp("^msgstr\\[[0-9]\\]\\s*\"?.*\\n?\"?$")))
+                     && (line.find(QRegExp("^msgstr\\[[0-9]\\]\\s*\"?.*\\n?\"?$")) != -1))
             {
                // remove quotes at beginning and the end of the lines
-               line.replace(QRegExp("^msgstr\\[[0-9]\\]\\s*\"?"),"");
-               line.replace(QRegExp("\"$"),"");
+               line.remove(QRegExp("^msgstr\\[[0-9]\\]\\s*\"?"));
+               line.remove(QRegExp("\"$"));
 
                msgstrIt=_msgstr.append(line);
 
-			   if(!line.isEmpty())
-			       recoverableError=true;
+               if(!line.isEmpty())
+                  recoverableError=true;
             }
-            else if(line.contains(QRegExp("^\\s*msgid")) || line.contains(QRegExp("^\\s*#")))
+            else if((line.find(QRegExp("^\\s*msgid")) != -1) || (line.find(QRegExp("^\\s*#")) != -1))
             {
                cancelLoop=true;
                stream.device()->at(pos);// reset position in stream to beginning of this line
                break;
             }
-            else if(line.contains(QRegExp("^msgstr")))
+            else if(line.startsWith("msgstr"))
             {
                kdDebug(KBABEL) << "no msgid or comment found after a msgstr while parsing: " << _msgstr.last() << endl;
 
@@ -665,13 +715,13 @@ ConversionStatus GettextImportPlugin::readEntry(QTextStream& stream)
                error=true;
             }
             // another line of the msgstr with a missing quotation mark
-            else if(line.contains(QRegExp("^\"?.+\\n?\"?$")))
+            else if(line.find(QRegExp("^\"?.+\\n?\"?$")) != -1)
             {
                recoverableError=true;
 
                // remove quotes at beginning and the end of the lines
-               line.replace(QRegExp("^\""),"");
-               line.replace(QRegExp("\"$"),"");
+               line.remove(QRegExp("^\""));
+               line.remove(QRegExp("\"$"));
 
                if((*msgstrIt).isEmpty())
                   (*msgstrIt)=line;
@@ -687,6 +737,7 @@ ConversionStatus GettextImportPlugin::readEntry(QTextStream& stream)
             }
         }
     }
+
 /*
    if(_gettextPluralForm)
    {
