@@ -3,8 +3,8 @@
 
   Copyright (C) 1999-2000 by Matthias Kiefer
                             <matthias.kiefer@gmx.de>
-		2002-2004 by Stanislav Visnovsky
-			    <visnovsky@kde.org>
+                2002-2004 by Stanislav Visnovsky
+                            <visnovsky@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -18,7 +18,18 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+
+  In addition, as a special exception, the copyright holders give
+  permission to link the code of this program with any edition of
+  the Qt library by Trolltech AS, Norway (or with modified versions
+  of Qt that use the same license as Qt), and distribute linked
+  combinations including the two.  You must obey the GNU General
+  Public License in all respects for all of the code used other than
+  Qt. If you modify this file, you may extend this exception to
+  your version of the file, but you are not obligated to do so.  If
+  you do not wish to do so, delete this exception statement from
+  your version.
 
 **************************************************************************** */
 
@@ -103,23 +114,39 @@ class MyKProgress: public KProgress
 public:
     MyKProgress( QWidget *parent, const char *name ) : KProgress( parent, name )
     {
-	setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Preferred );
+        setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Preferred );
     }
     QSize sizeHint() const { return QSize( 1, 1);}
 };
 
 KBabelMW::KBabelMW(QString projectFile)
-	: KDockMainWindow (), m_charselectorview(0)
+        : KDockMainWindow (), m_charselectorview(0)
 {
     _project = ProjectManager::open(projectFile);
+    
+    if ( _project == NULL )
+    {
+	KMessageBox::error( this, i18n("Cannot open project file\n%1").arg(projectFile)
+            , i18n("Project File Error"));
+	_project = ProjectManager::open(KBABEL_DEFAULTPROJECT);
+    }
+    
     KBCatalog* catalog=new KBCatalog(projectFile);
     init(catalog);
 }
 
 KBabelMW::KBabelMW(KBCatalog* catalog, QString projectFile)
-	: KDockMainWindow (), m_charselectorview(0)
+        : KDockMainWindow (), m_charselectorview(0)
 {
     _project = ProjectManager::open(projectFile);
+
+    if ( _project == NULL )
+    {
+	KMessageBox::error( this, i18n("Cannot open project file\n%1").arg(projectFile)
+            , i18n("Project File Error"));
+	_project = ProjectManager::open(KBABEL_DEFAULTPROJECT);
+    }
+    
     init(catalog);
 }
 
@@ -140,7 +167,7 @@ void KBabelMW::init(KBCatalog* catalog)
 
     _statusbarTimer = new QTimer(this, "statusbartimer");
     connect(_statusbarTimer,SIGNAL(timeout()),this
-	,SLOT(clearStatusbarMsg()));
+        ,SLOT(clearStatusbarMsg()));
 
     // FIXME:
     Q_ASSERT(_project);
@@ -161,17 +188,17 @@ void KBabelMW::init(KBCatalog* catalog)
     stateChanged( "fileopened" , StateReverse );
     stateChanged( "readonly", StateNoReverse );
 
-	QPopupMenu* popup;
-	popup = (QPopupMenu*)(factory()->container("rmb_edit", this));
-	if(popup)
-	{
-		m_view->setRMBEditMenu(popup);
-	}
-	popup = (QPopupMenu*)(factory()->container("rmb_search", this));
-	if(popup)
-	{
-		m_view->setRMBSearchMenu(popup);
-	}
+        QPopupMenu* popup;
+        popup = (QPopupMenu*)(factory()->container("rmb_edit", this));
+        if(popup)
+        {
+                m_view->setRMBEditMenu(popup);
+        }
+        popup = (QPopupMenu*)(factory()->container("rmb_search", this));
+        if(popup)
+        {
+                m_view->setRMBSearchMenu(popup);
+        }
 
 
     connect(catalog,SIGNAL(signalUndoAvailable(bool)),this
@@ -255,10 +282,10 @@ void KBabelMW::init(KBCatalog* catalog)
 
        m_view->emitEntryState();
 
-       changeCaption(catalog->currentURL().prettyURL());
+       changeCaption(catalog->currentURL().prettyURL() );
     }
 
-    mailer = new KBabelMailer( _project->filename() );
+    mailer = new KBabelMailer( _project );
 
     bmHandler = new KBabelBookmarkHandler((QPopupMenu*)factory()->container("bookmark", this));
     // the earlier created KAction for "clear_bookmarks" is now reconnected
@@ -266,12 +293,12 @@ void KBabelMW::init(KBCatalog* catalog)
     if (action) {
       action->disconnect(SIGNAL(activated()));
       connect(action, SIGNAL(activated()),
-	      bmHandler, SLOT(slotClearBookmarks()));
+              bmHandler, SLOT(slotClearBookmarks()));
     }
     connect(bmHandler, SIGNAL(signalBookmarkSelected(int)),
-	    this, SLOT(slotOpenBookmark(int)));
+            this, SLOT(slotOpenBookmark(int)));
     connect(m_view, SIGNAL(signalNewFileOpened(KURL)),
-	    bmHandler, SLOT(slotClearBookmarks()));
+            bmHandler, SLOT(slotClearBookmarks()));
 
     _config = KSharedConfig::openConfig( "kbabelrc" );
     restoreSettings();
@@ -283,10 +310,10 @@ void KBabelMW::init(KBCatalog* catalog)
       QString encodingStr;
       switch(catalog->saveSettings().encoding)
       {
-         case UTF8:
+         case KBabel::ProjectSettingsBase::UTF8:
             encodingStr=QTextCodec::codecForName("UTF-8")->name();
             break;
-         case UTF16:
+         case KBabel::ProjectSettingsBase::UTF16:
             encodingStr=QTextCodec::codecForName("UTF-16")->name();
             break;
          default:
@@ -296,14 +323,14 @@ void KBabelMW::init(KBCatalog* catalog)
       if( KBabelSplash::instance ) KBabelSplash::instance->close(); //close splash screen window, if there is one
 
       KMessageBox::information(0,i18n("You have not run KBabel before. "
-		   "To allow KBabel to work correctly you must enter some "
-		   "information in the preferences dialog first.\n"
-		   "The minimum requirement is to fill out the Identity page.\n"
-		   "Also check the encoding on the Save page, which is currently "
-		   "set to %1. You may want to change this setting "
-		   "according to the settings of your language team.").arg(encodingStr));
+                   "To allow KBabel to work correctly you must enter some "
+                   "information in the preferences dialog first.\n"
+                   "The minimum requirement is to fill out the Identity page.\n"
+                   "Also check the encoding on the Save page, which is currently "
+                   "set to %1. You may want to change this setting "
+                   "according to the settings of your language team.").arg(encodingStr));
 
-      QTimer::singleShot(1,this,SLOT(optionsPreferences()));
+      QTimer::singleShot(1,this,SLOT(projectConfigure()));
     }
 
     _config->writeEntry("Version",VERSION);
@@ -376,14 +403,14 @@ void KBabelMW::setupActions()
 
    a_recent = KStdAction::openRecent(this, SLOT(openRecent(const KURL&)), actionCollection());
    a_recent->setMaxItems(MAX_RECENT);
-
+   
    action = KStdAction::revert(m_view,SLOT(revertToSaved()),actionCollection());
    action=KStdAction::save(this, SLOT(fileSave()), actionCollection());
    action = KStdAction::saveAs(this, SLOT(fileSaveAs()), actionCollection());
    action = new KAction(i18n("Save Sp&ecial..."), 0, this, SLOT(fileSaveSpecial()),
-	 actionCollection(), "save_special" );
+         actionCollection(), "save_special" );
    action = new KAction(i18n("Set &Package..."), 0, m_view, SLOT(setFilePackage()),
-	 actionCollection(), "set_package" );
+         actionCollection(), "set_package" );
 
    action = KStdAction::mail(this, SLOT(fileMail()), actionCollection());
 
@@ -415,8 +442,8 @@ void KBabelMW::setupActions()
    action = new KAction(i18n("Cop&y Msgid to Msgstr"), "msgid2msgstr", CTRL+Key_Space, m_view
                  ,SLOT(msgid2msgstr()), actionCollection(), "msgid2msgstr");
    action = new KAction(i18n("Copy Searc&h Result to Msgstr"), "search2msgstr",
-			CTRL+ALT+Key_Space, m_view, SLOT(search2msgstr()),
-			actionCollection(), "search2msgstr");
+                        CTRL+ALT+Key_Space, m_view, SLOT(search2msgstr()),
+                        actionCollection(), "search2msgstr");
    action = new KAction(i18n("Copy Msgstr to Other &Plurals"), Key_F11, m_view
                    ,SLOT(plural2msgstr()), actionCollection(), "plural2msgstr");
    action = new KAction(i18n("Copy Selected Character to Msgstr"), Key_F10, m_charselectorview
@@ -432,7 +459,7 @@ void KBabelMW::setupActions()
            , actionCollection(),"insert_next_tag");
    connect(m_view,SIGNAL(signalNextTagAvailable(bool)),action
            ,SLOT(setEnabled(bool)));
-   action = new KAction(i18n("Insert Next Tag From Msgid P&osition"), "insert_tag", CTRL+ALT+Key_M
+   action = new KAction(i18n("Insert Next Tag From Msgid P&osition"), "insert_tag", CTRL+Key_M
            , m_view, SLOT(insertNextTagMsgid())
            , actionCollection(),"insert_next_tag_msgid");
    connect(m_view,SIGNAL(signalNextTagAvailable(bool)),action
@@ -451,11 +478,11 @@ void KBabelMW::setupActions()
    connect(m_view,SIGNAL(signalTagsAvailable(bool)),action
            ,SLOT(setEnabled(bool)));
 
-   action = new KAction(i18n("Move to Next Tag"), 0, CTRL+Key_Plus
+   action = new KAction(i18n("Move to Next Tag"), 0, CTRL+ALT+Key_M
            , m_view, SLOT(skipToNextTag())
            , actionCollection(),"move_to_next_tag");
 
-   action = new KAction(i18n("Move to Previous Tag"), 0, CTRL+Key_Minus
+   action = new KAction(i18n("Move to Previous Tag"), 0, CTRL+ALT+Key_B
            , m_view, SLOT(skipToPreviousTag())
            , actionCollection(),"move_to_prev_tag");
 
@@ -517,9 +544,9 @@ void KBabelMW::setupActions()
    action = new KAction(i18n("Next Err&or"), "nexterror",
          SHIFT+Key_Next, m_view,
          SLOT(gotoNextError()),actionCollection(), "go_next_error");
-   action = new KAction(i18n("&Back"), "back", ALT+Key_Left, m_view,
+   action = new KAction(i18n("&Back in History"), "back", ALT+Key_Left, m_view,
          SLOT(backHistory()),actionCollection(), "go_back_history");
-   action = new KAction(i18n("For&ward"), "forward", ALT+Key_Right, m_view,
+   action = new KAction(i18n("For&ward in History"), "forward", ALT+Key_Right, m_view,
          SLOT(forwardHistory()),actionCollection(), "go_forward_history");
 
     // the search menu
@@ -576,6 +603,8 @@ void KBabelMW::setupActions()
            , this, SLOT(projectConfigure()),actionCollection()
            ,"project_settings");
 
+   a_recentprojects = new KRecentFilesAction(i18n("Open &Recent"), 0, this, SLOT(projectOpenRecent(const KURL&)), actionCollection(), "recent_projects");
+
     // the tools menu
    action = new KAction(i18n("&Spell Check..."), "spellcheck", CTRL+Key_I
            , m_view, SLOT(spellcheckCommon()),actionCollection()
@@ -624,6 +653,8 @@ void KBabelMW::setupActions()
          SLOT(openCatalogManager()),actionCollection(), "open_catalog_manager");
 
    new KAction( i18n("Toggle Edit Mode"), 0, Key_Insert,this,SLOT(toggleEditMode()), actionCollection(), "toggle_insert_mode");
+   
+   new KAction( i18n("&Word Count"), 0, m_view, SLOT(wordCount()), actionCollection(), "word_count");   
 
     // next, the settings menu
     createStandardStatusBarAction();
@@ -749,7 +780,7 @@ void KBabelMW::setupDynamicActions()
 
    // query available tools
    QValueList<KDataToolInfo> allTools = KDataToolInfo::query
-	("CatalogItem", "application/x-kbabel-catalogitem", KGlobal::instance());
+        ("CatalogItem", "application/x-kbabel-catalogitem", KGlobal::instance());
 
    // skip read-only tools for single items
    QValueList<KDataToolInfo> modifyTools;
@@ -757,10 +788,10 @@ void KBabelMW::setupDynamicActions()
    QValueList<KDataToolInfo>::ConstIterator entry = allTools.begin();
    for( ; entry != allTools.end(); ++entry )
    {
-	if( !(*entry).isReadOnly() )
-	{
-	    modifyTools.append( (*entry) );
-	}
+        if( !(*entry).isReadOnly() )
+        {
+            modifyTools.append( (*entry) );
+        }
    }
 
    // create corresponding actions
@@ -783,16 +814,16 @@ void KBabelMW::setupDynamicActions()
 
    // query available tools for whole catalog
    allTools = KDataToolInfo::query
-	("Catalog", "application/x-kbabel-catalog", KGlobal::instance());
+        ("Catalog", "application/x-kbabel-catalog", KGlobal::instance());
 
    // skip read-only tools
    entry = allTools.begin();
    for( ; entry != allTools.end(); ++entry )
    {
-	if( !(*entry).isReadOnly() )
-	{
-	    modifyTools.append( (*entry) );
-	}
+        if( !(*entry).isReadOnly() )
+        {
+            modifyTools.append( (*entry) );
+        }
    }
 
    // create corresponding actions
@@ -822,12 +853,13 @@ void KBabelMW::setupDynamicActions()
 void KBabelMW::saveSettings()
 {
     {
-	saveMainWindowSettings(_config, "View");
-	writeDockConfig (_config, "View");
+        saveMainWindowSettings(_config, "View");
+        writeDockConfig (_config, "View");
     }
 
     {
        a_recent->saveEntries(_config);
+       a_recentprojects->saveEntries(_config,"Project");
     }
 
     _config->sync();
@@ -842,20 +874,13 @@ void KBabelMW::restoreSettings()
        _config->setGroup("View");
        m_view->restoreView(_config);
 
-	readDockConfig (_config, "View");
+        readDockConfig (_config, "View");
     }
 
     {
        a_recent->loadEntries(_config);
 
-       // cleanup maybe broken list
-       QStringList list = a_recent->items();
-       QStringList result;
-       for ( QStringList::Iterator it = list.begin(); it != list.end(); ++it ) {
-           KURL u( *it );
-	   if( u.isValid() && !u.isEmpty() ) result.append( *it );
-       }
-       a_recent->setItems(result);
+       a_recentprojects->loadEntries(_config, "Project");
     }
 }
 
@@ -885,7 +910,7 @@ void KBabelMW::readProperties(KConfig *config)
 
        m_view->emitEntryState();
 
-       changeCaption(catalog->currentURL().prettyURL());
+       changeCaption(catalog->currentURL().prettyURL() );
     }
 }
 
@@ -959,6 +984,11 @@ void KBabelMW::dropEvent(QDropEvent *event)
     }
 }
 
+void KBabelMW::wheelEvent(QWheelEvent *e)
+{
+    m_view->wheelEvent(e);
+}
+
 void KBabelMW::openRecent(const KURL& url)
 {
    KBabelView *view = KBabelView::viewForURL(url,QString::null);
@@ -983,7 +1013,7 @@ void KBabelMW::open(const KURL& url, const QString package, bool newWindow)
    KBabelView *view = KBabelView::viewForURL(url, _project->filename());
    if(view)
    {
-	kdDebug(KBABEL) << "there is a such view" << endl;
+        kdDebug(KBABEL) << "there is a such view" << endl;
        KWin::activateWindow(view->topLevelWidget()->winId());
        return;
    }
@@ -992,7 +1022,7 @@ void KBabelMW::open(const KURL& url, const QString package, bool newWindow)
 
    if(newWindow)
    {
-	kdDebug(KBABEL) << "creating new window"<< endl;
+        kdDebug(KBABEL) << "creating new window"<< endl;
       fileNewWindow()->open(url, package,false);
    }
    else
@@ -1026,7 +1056,7 @@ void KBabelMW::fileOpen()
 void KBabelMW::addToRecentFiles(KURL url)
 {
    if( url.isValid() && ! url.isEmpty() )
-	a_recent->addURL(url);
+        a_recent->addURL(url);
 }
 
 void KBabelMW::fileSave()
@@ -1077,7 +1107,7 @@ void KBabelMW::fileSaveAs()
     QDataStream arg(data, IO_WriteOnly);
     arg << ((url.directory(false)+url.fileName()).utf8())  ;
     if( !client->send( "catalogmanager-*", "CatalogManagerIFace", "updatedFile(QCString)", data ))
-	kdDebug(KBABEL) << "Unable to send file update info via DCOP" << endl;
+        kdDebug(KBABEL) << "Unable to send file update info via DCOP" << endl;
 }
 
 void KBabelMW::fileSaveSpecial()
@@ -1091,7 +1121,7 @@ void KBabelMW::fileSaveSpecial()
     QDataStream arg(data, IO_WriteOnly);
     arg << ((url.directory(false)+url.fileName()).utf8())  ;
     if( !client->send( "catalogmanager-*", "CatalogManagerIFace", "updatedFile(QCString)", data ))
-	kdDebug(KBABEL) << "Unable to send file update info via DCOP" << endl;
+        kdDebug(KBABEL) << "Unable to send file update info via DCOP" << endl;
 }
 
 void KBabelMW::fileMail()
@@ -1211,28 +1241,28 @@ void KBabelMW::openCatalogManager()
 
     // find out, if there is a running catalog manager
     QCStringList apps = client->registeredApplications();
-    for( QCStringList::Iterator it = apps.begin() ; it != apps.end() ; it++ )
+    for( QCStringList::Iterator it = apps.begin() ; it != apps.end() ; ++it )
     {
-	QString clientID = *it;
-	if( clientID.startsWith("catalogmanager") )
-	{
-	    service = *it;
-	    break;
-	}
+        QString clientID = *it;
+        if( clientID.startsWith("catalogmanager") )
+        {
+            service = *it;
+            break;
+        }
     }
 
     // if there is no running catalog manager, start one
     if( service.isEmpty() )
     {
-	QString prog = "catalogmanager";
-	QString url = "";
-	if( kapp->startServiceByDesktopName(prog,url, &result,&service))
-	{
-	     KMessageBox::error(this, i18n("Unable to use KLauncher to start "
-	        "Catalog Manager. You should check the installation of KDE.\n"
-		"Please start Catalog Manager manually."));
-	     return;
-	}
+        QString prog = "catalogmanager";
+        QString url = "";
+        if( kapp->startServiceByDesktopName(prog,url, &result,&service))
+        {
+             KMessageBox::error(this, i18n("Unable to use KLauncher to start "
+                "Catalog Manager. You should check the installation of KDE.\n"
+                "Please start Catalog Manager manually."));
+             return;
+        }
     }
 
     // set preferred window
@@ -1474,8 +1504,8 @@ void KBabelMW::changeCaption(const QString& text)
 {
     // display the text on the caption
     setCaption(text + ( _project->filename () != KBABEL_DEFAULTPROJECT ?
-	    " (" + _project->name() + ")" : "" /* KDE 3.4: i18n("(No project)")*/ )
-	,m_view->isModified());
+            " (" + _project->name() + ")" : "" /* KDE 3.4: i18n("(No project)")*/ )
+        ,m_view->isModified());
 }
 
 
@@ -1624,18 +1654,18 @@ void KBabelMW::spellcheckDone( int result)
 {
     if( _toSpellcheck.isEmpty() || result == KS_STOP)
     {
-	disconnect( m_view, SIGNAL( signalSpellcheckDone(int)), this, SLOT(spellcheckDone( int)));
-	KMessageBox::information( this, i18n("MessageBox text", "Spellchecking of multiple files is finished."),
-	    i18n("MessageBox caption", "Spellcheck Done"));
+        disconnect( m_view, SIGNAL( signalSpellcheckDone(int)), this, SLOT(spellcheckDone( int)));
+        KMessageBox::information( this, i18n("MessageBox text", "Spellchecking of multiple files is finished."),
+            i18n("MessageBox caption", "Spellcheck Done"));
     }
     else
     {
-	QString file = _toSpellcheck.first();
-	_toSpellcheck.pop_front();
-	if( m_view->isModified() ) fileSave();
-	open(KURL( file ), QString::null, false);
-	kdDebug(KBABEL) << "Starting another spellcheck" << endl;
-	QTimer::singleShot( 1, m_view, SLOT(spellcheckAllMulti()));
+        QString file = _toSpellcheck.first();
+        _toSpellcheck.pop_front();
+        if( m_view->isModified() ) fileSave();
+        open(KURL( file ), QString::null, false);
+        kdDebug(KBABEL) << "Starting another spellcheck" << endl;
+        QTimer::singleShot( 1, m_view, SLOT(spellcheckAllMulti()));
     }
 }
 
@@ -1663,9 +1693,9 @@ void KBabelMW::projectNew()
     KBabel::Project::Ptr p = KBabel::ProjectWizard::newProject();
     if( p )
     {
-	_project = p;
-	m_view->useProject(p);
-	changeProjectActions(p->filename());
+        _project = p;
+        m_view->useProject(p);
+        changeProjectActions(p->filename());
     }
 }
 
@@ -1674,19 +1704,26 @@ void KBabelMW::projectOpen()
     QString oldproject = m_view->project();
     if( oldproject == KBABEL_DEFAULTPROJECT )
     {
-	oldproject = "";
+        oldproject = QString();
     }
-    QString file = KFileDialog::getOpenFileName(oldproject, i18n("*|All Files"), this);
+    const QString file = KFileDialog::getOpenFileName(oldproject, QString::null, this);
     if (file.isEmpty())
     {
         return;
     }
-    KBabel::Project::Ptr p = KBabel::ProjectManager::open(file);
+    
+    projectOpen (file);
+}
+
+void KBabelMW::projectOpenRecent(const KURL& url)
+{
+    projectOpen (url.path());
+    KBabel::Project::Ptr p = KBabel::ProjectManager::open(url.path());
     if( p )
     {
-	_project = p;
-	m_view->useProject(p);
-	changeProjectActions(file);
+        _project = p;
+        m_view->useProject(p);
+        changeProjectActions(url.path());
     }
 }
 
@@ -1695,7 +1732,7 @@ void KBabelMW::projectOpen(const QString& file)
     QString oldproject = m_view->project();
     if( oldproject == KBABEL_DEFAULTPROJECT )
     {
-	oldproject = "";
+        oldproject = "";
     }
     if (file.isEmpty())
     {
@@ -1704,15 +1741,24 @@ void KBabelMW::projectOpen(const QString& file)
     KBabel::Project::Ptr p = KBabel::ProjectManager::open(file);
     if( p )
     {
-	_project = p;
-	m_view->useProject(p);
-	changeProjectActions(file);
+        _project = p;
+        m_view->useProject(p);
+        changeProjectActions(file);
+    }
+    else 
+    {
+	KMessageBox::error( this, i18n("Cannot open project file\n%1").arg(file)
+            , i18n("Project File Error"));
+	_project = ProjectManager::open(KBABEL_DEFAULTPROJECT);
+	m_view->useProject(_project);
+	changeProjectActions(KBABEL_DEFAULTPROJECT);
     }
 }
 
 void KBabelMW::projectClose()
 {
     m_view->useProject( KBabel::ProjectManager::open(KBABEL_DEFAULTPROJECT) );
+    _project = ProjectManager::open(KBABEL_DEFAULTPROJECT);
     changeProjectActions(KBABEL_DEFAULTPROJECT);
 }
 
@@ -1722,6 +1768,18 @@ void KBabelMW::changeProjectActions(const QString& project)
 
     KAction* saveAction=(KAction*)actionCollection()->action( "project_close" );
     saveAction->setEnabled( ! def );
+    
+    if (!def)
+    {
+	addToRecentProjects(project);
+    }
+    
+    // if there is a project dialog, delete it (we have a different project now
+    if (_projectDialog) 
+    {
+	delete _projectDialog;
+	_projectDialog = NULL;
+    }
 }
 
 void KBabelMW::projectConfigure()
@@ -1729,6 +1787,8 @@ void KBabelMW::projectConfigure()
     if(!_projectDialog)
     {
         _projectDialog = new ProjectDialog(_project);
+	connect (_projectDialog, SIGNAL (settingsChanged())
+	    , m_view, SLOT (updateProjectSettings()));
     }
 
     int prefHeight=_projectDialog->height();
@@ -1750,4 +1810,11 @@ void KBabelMW::projectConfigure()
     KWin::activateWindow(_projectDialog->winId());
 }
 
+void KBabelMW::addToRecentProjects(KURL url)
+{
+   if( url.isValid() && ! url.isEmpty() )
+	a_recentprojects->addURL(url);
+}
+
+
 #include "kbabel.moc"
