@@ -18,7 +18,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
@@ -507,7 +507,7 @@ int main(int argc, char **argv)
 {
     KAboutData about("kbabel",I18N_NOOP("KBabel"),VERSION,
        I18N_NOOP("An advanced PO file editor"),KAboutData::License_GPL,
-       I18N_NOOP("(c) 1999,2000,2001,2002,2003,2004,2005 The KBabel developers"),0,"http://i18n.kde.org/tools/kbabel");
+       I18N_NOOP("(c) 1999,2000,2001,2002,2003,2004,2005,2006 The KBabel developers"),0,"http://i18n.kde.org/tools/kbabel");
 
     about.addAuthor("Matthias Kiefer",I18N_NOOP("Original author"),"kiefer@kde.org");
     about.addAuthor("Wolfram Diestel"
@@ -522,6 +522,7 @@ int main(int argc, char **argv)
          ,"dubbleu@web.de");
     about.addAuthor("Asgeir Frimannsson",I18N_NOOP("Translation List View")
          ,"asgeirf@redhat.com");
+    about.addAuthor("Nicolas Goutte", I18N_NOOP("Current maintainer"), "goutte@kde.org");
 
     about.addCredit("Claudiu Costin",I18N_NOOP("Wrote documentation and sent "
 		"many bug reports and suggestions for improvements.")
@@ -538,14 +539,11 @@ int main(int argc, char **argv)
 	about.addCredit("SuSE GmbH"
 					,I18N_NOOP("Sponsored development of KBabel for a while.")
 					,"suse@suse.de","http://www.suse.de");
-    about.addCredit("",
-            I18N_NOOP("KBabel contains code from the following projects:\n"
-            "Qt by Trolltech"));
+    about.addCredit("Trolltech", I18N_NOOP("KBabel contains code from Qt"), 0, "http://www.trolltech.com");
 
     about.addCredit("Eva Brucherseifer", I18N_NOOP("String difference algorithm implementation"), "eva@kde.org");
 
-    about.setTranslator(I18N_NOOP("_: NAME OF TRANSLATORS\nYour names")
-            ,I18N_NOOP("_: EMAIL OF TRANSLATORS\nYour emails"));
+    about.addCredit("Albert Cervera Areny", I18N_NOOP("Error list for current entry, regexp data tool"), "albertca@hotpop.com");
 
     // Initialize command line args
     KCmdLineArgs::init(argc, argv, &about);
