@@ -20,12 +20,6 @@
 #ifndef KOMPARESHELL_H
 #define KOMPARESHELL_H
 
-/* there is no config.h used yet, so disabling
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-*/
-
 #include <kapplication.h>
 #include <kparts/dockmainwindow.h>
 
@@ -37,6 +31,12 @@ class KSqueezedTextLabel;
 class KomparePart;
 class KompareNavTreePart;
 
+namespace KTextEditor {
+	class Document;
+	class EditInterface;
+	class View;
+}
+
 /**
 * This is the application "Shell".  It has a menubar, toolbar, and
 * statusbar but relies on the "Part" to do all the real work.
@@ -46,7 +46,7 @@ class KompareNavTreePart;
 * @short Application Shell
 * @author John Firebaugh <jfirebaugh@kde.org>
 * @author Otto Bruggeman <bruggie@home.nl>
-* @version 3.2
+* @version 3.2.90
 */
 class KompareShell : public KParts::DockMainWindow
 {
@@ -86,6 +86,11 @@ public slots:
 	void slotUpdateStatusBar( int modelIndex, int differenceIndex, int modelCount, int differenceCount, int appliedCount );
 	void setCaption( const QString& caption );
 
+	/**
+	 * This method only exists because i cant make main a frined of this class
+	 */
+	KomparePart* viewPart() const { return m_viewPart; }
+
 protected:
 	virtual bool queryClose();
 
@@ -111,7 +116,7 @@ private slots:
 	void slotFileClose();
 	void optionsConfigureKeys();
 	void optionsConfigureToolbars();
-	void slotDiffURLChanged();
+	void slotSetDiffString( const QString& diffString );
 	void newToolbarConfig();
 
 private:
@@ -120,23 +125,25 @@ private:
 	void setupStatusBar();
 
 private:
-	KURL                  m_sourceURL;
-	KURL                  m_destinationURL;
-	KURL                  m_diffURL;
+	KURL                        m_sourceURL;
+	KURL                        m_destinationURL;
+	KURL                        m_diffURL;
 
-	KomparePart*          m_viewPart;
-	KompareNavTreePart*   m_navTreePart;
-	KParts::ReadOnlyPart* m_textViewPart;
+	KomparePart*                m_viewPart;
+	KompareNavTreePart*         m_navTreePart;
+	KTextEditor::Document*      m_textViewPart;
+	KTextEditor::View*          m_textView;
+	KTextEditor::EditInterface* m_textEditIface;
 
-	KDockWidget*          m_textViewWidget;
-	KDockWidget*          m_mainViewDock;
-	KDockWidget*          m_navTreeDock;
+	KDockWidget*                m_textViewWidget;
+	KDockWidget*                m_mainViewDock;
+	KDockWidget*                m_navTreeDock;
 
-	KToggleAction*        m_showTextView;
+	KToggleAction*              m_showTextView;
 
-	enum Kompare::Mode    m_mode;
+	enum Kompare::Mode          m_mode;
 	// This is the statusbarwidget for displaying the general stuff
-	KSqueezedTextLabel*   m_generalLabel;
+	KSqueezedTextLabel*         m_generalLabel;
 };
 
 #endif // KOMPARE_H
