@@ -30,6 +30,7 @@
 #include "viewsettings.h"
 #include "komparemodellist.h"
 #include "komparelistview.h"
+#include "komparesplitter.h"
 
 #include "kompareconnectwidget.h"
 
@@ -48,12 +49,16 @@ KompareConnectWidgetFrame::KompareConnectWidgetFrame( KompareListView* left,
 	setSizePolicy ( QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Ignored) );
 	m_wid.setSizePolicy ( QSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored) );
 	m_label.setSizePolicy ( QSizePolicy(QSizePolicy::Ignored, QSizePolicy::Fixed) );
-	m_label.setFrameShape( QFrame::StyledPanel );
-	m_label.setFrameShadow ( QFrame::Plain );
 	m_label.setMargin(3);
+	QFrame* bottomLine = new QFrame(this);
+	bottomLine->setFrameShape(QFrame::HLine);
+	bottomLine->setFrameShadow ( QFrame::Plain );
+	bottomLine->setSizePolicy ( QSizePolicy(QSizePolicy::Ignored, QSizePolicy::Fixed) );
+	bottomLine->setFixedHeight(1);
 	m_layout.setSpacing(0);
 	m_layout.setMargin(0);
 	m_layout.addWidget(&m_label);
+	m_layout.addWidget(bottomLine);
 	m_layout.addWidget(&m_wid);
 }
 
@@ -66,6 +71,35 @@ QSize KompareConnectWidgetFrame::sizeHint() const
 	return QSize(50, style().pixelMetric( QStyle::PM_ScrollBarExtent ) );
 }
 
+static int kMouseOffset;
+
+void KompareConnectWidgetFrame::mouseMoveEvent( QMouseEvent *e )
+{
+	if ( !(e->state()&LeftButton) )
+		return;
+
+	QCOORD pos = s->pick( parentWidget()->mapFromGlobal(e->globalPos()) )
+		- kMouseOffset;
+
+	((KompareSplitter*)s)->moveSplitter( pos, id() );
+}
+
+void KompareConnectWidgetFrame::mousePressEvent( QMouseEvent *e )
+{
+	if ( e->button() == LeftButton )
+		kMouseOffset = s->pick( e->pos() );
+	QSplitterHandle::mousePressEvent(e);
+}
+
+void KompareConnectWidgetFrame::mouseReleaseEvent( QMouseEvent *e )
+{
+	if ( !opaque() && e->button() == LeftButton ) {
+		QCOORD pos = s->pick( parentWidget()->mapFromGlobal(e->globalPos()) )
+			- kMouseOffset;
+		((KompareSplitter*)s)->moveSplitter( pos, id() );
+    }
+}
+
 KompareConnectWidget::KompareConnectWidget( KompareListView* left, KompareListView* right,
       ViewSettings* settings, QWidget* parent, const char* name )
 	: QWidget(parent, name),
@@ -75,9 +109,10 @@ KompareConnectWidget::KompareConnectWidget( KompareListView* left, KompareListVi
 	m_selectedModel( 0 ),
 	m_selectedDifference( 0 )
 {
-	connect( m_settings, SIGNAL( settingsChanged() ), this, SLOT( slotDelayedRepaint() ) );
+//	connect( m_settings, SIGNAL( settingsChanged() ), this, SLOT( slotDelayedRepaint() ) );
 	setBackgroundMode( NoBackground );
 	setSizePolicy( QSizePolicy( QSizePolicy::Fixed, QSizePolicy::Minimum ) );
+	setFocusProxy( parent->parentWidget() );
 }
 
 KompareConnectWidget::~KompareConnectWidget()
@@ -125,7 +160,7 @@ void KompareConnectWidget::paintEvent( QPaintEvent* /* e */ )
 	QPainter paint(&pixbuf, this);
 	QPainter* p = &paint;
 
-	p->fillRect( 0, 0, pixbuf.width(), pixbuf.height(), white );
+	p->fillRect( 0, 0, pixbuf.width(), pixbuf.height(), white.dark(110) );
 
 	if ( m_selectedModel )
 	{
@@ -179,14 +214,14 @@ void KompareConnectWidget::paintEvent( QPaintEvent* /* e */ )
 				QPointArray topBezier = makeTopBezier( tl, tr );
 				QPointArray bottomBezier = makeBottomBezier( bl, br );
 
-				QColor color = m_settings->colorForDifferenceType( diff->type(), selected, diff->applied() );
+				QColor color = m_settings->colorForDifferenceType( diff->type(), selected, diff->applied() ).dark(110);
 				p->setPen( color );
 				p->setBrush( color );
 				p->drawPolygon ( makeConnectPoly( topBezier, bottomBezier ) );
 
 				if ( selected )
 				{
-					p->setPen( black );
+					p->setPen( color.dark(135) );
 					p->drawPolyline( topBezier );
 					p->drawPolyline( bottomBezier );
 				}
@@ -194,10 +229,6 @@ void KompareConnectWidget::paintEvent( QPaintEvent* /* e */ )
 		}
 	}
 
-	p->setPen( black );
-	p->drawLine( 0,0, 0,pixbuf.height() );
-	p->drawLine( pixbuf.width()-1,0, pixbuf.width()-1,pixbuf.height() );
-
 	p->flush();
 	bitBlt(this, 0, 0, &pixbuf);
 }
