@@ -41,39 +41,41 @@ ParserBase::ParserBase( const KompareModelList* list, const QStringList& diff )
 	m_models = new DiffModelList();
 
 	// used in contexthunkheader
-	m_contextHunkHeader1.setPattern( "^\\*{15} ?(.*)$" ); // capture is for function name
-	m_contextHunkHeader2.setPattern( "^\\*\\*\\* ([0-9]+),([0-9]+) \\*\\*\\*\\*$" );
+	m_contextHunkHeader1.setPattern( "\\*{15} ?(.*)\\n" ); // capture is for function name
+	m_contextHunkHeader2.setPattern( "\\*\\*\\* ([0-9]+),([0-9]+) \\*\\*\\*\\*\\n" );
 	// used in contexthunkbody
-	m_contextHunkHeader3.setPattern( "^--- ([0-9]+),([0-9]+) ----$" );
+	m_contextHunkHeader3.setPattern( "--- ([0-9]+),([0-9]+) ----\\n" );
 
-	m_contextHunkBodyRemoved.setPattern( "^- (.*)$" );
-	m_contextHunkBodyAdded.setPattern  ( "^\\+ (.*)$" );
-	m_contextHunkBodyChanged.setPattern( "^! (.*)$" );
-	m_contextHunkBodyContext.setPattern( "^  (.*)$" );
-	m_contextHunkBodyLine.setPattern   ( "^[-\\+! ] (.*)$" );
+	m_contextHunkBodyRemoved.setPattern( "- (.*)" );
+	m_contextHunkBodyAdded.setPattern  ( "\\+ (.*)" );
+	m_contextHunkBodyChanged.setPattern( "! (.*)" );
+	m_contextHunkBodyContext.setPattern( "  (.*)" );
+	m_contextHunkBodyLine.setPattern   ( "[-\\+! ] (.*)" );
 
 	// This regexp sucks... i'll see what happens
-	m_normalDiffHeader.setPattern( "^diff (?:(?:-|--)[a-zA-Z0-9=\\\"]+ )*(?:|-- +)(.*) +(.*)$" );
+	m_normalDiffHeader.setPattern( "diff (?:(?:-|--)[a-zA-Z0-9=\\\"]+ )*(?:|-- +)(.*) +(.*)\\n" );
 
-	m_normalHunkHeaderAdded.setPattern  ( "^([0-9]+)a([0-9]+)(|,[0-9]+)(.*)$" );
-	m_normalHunkHeaderRemoved.setPattern( "^([0-9]+)(|,[0-9]+)d([0-9]+)(.*)$" );
-	m_normalHunkHeaderChanged.setPattern( "^([0-9]+)(|,[0-9]+)c([0-9]+)(|,[0-9]+)(.*)$" );
+	m_normalHunkHeaderAdded.setPattern  ( "([0-9]+)a([0-9]+)(|,[0-9]+)(.*)\\n" );
+	m_normalHunkHeaderRemoved.setPattern( "([0-9]+)(|,[0-9]+)d([0-9]+)(.*)\\n" );
+	m_normalHunkHeaderChanged.setPattern( "([0-9]+)(|,[0-9]+)c([0-9]+)(|,[0-9]+)(.*)\\n" );
 
-	m_normalHunkBodyRemoved.setPattern  ( "^< (.*)$" );
-	m_normalHunkBodyAdded.setPattern    ( "^> (.*)$" );
-	m_normalHunkBodyDivider.setPattern  ( "^---$" );
+	m_normalHunkBodyRemoved.setPattern  ( "< (.*)" );
+	m_normalHunkBodyAdded.setPattern    ( "> (.*)" );
+	m_normalHunkBodyDivider.setPattern  ( "---" );
 
-	m_unifiedDiffHeader1.setPattern    ( "^--- ([^\\t]+)\\t([^\\t]+)(?:\\t?)(.*)$" );
-	m_unifiedDiffHeader2.setPattern    ( "^\\+\\+\\+ ([^\\t]+)\\t([^\\t]+)(?:\\t?)(.*)$" );
-	m_unifiedHunkHeader.setPattern     ( "^@@ -([0-9]+)(|,([0-9]+)) \\+([0-9]+)(|,([0-9]+)) @@(?: ?)(.*)$" );
-	m_unifiedHunkBodyAdded.setPattern  ( "^\\+(.*)$" );
-	m_unifiedHunkBodyRemoved.setPattern( "^-(.*)$" );
-	m_unifiedHunkBodyContext.setPattern( "^ (.*)$" );
-	m_unifiedHunkBodyLine.setPattern   ( "^([-+ ])(.*)$" );
+	m_unifiedDiffHeader1.setPattern    ( "--- ([^\\t]+)\\t([^\\t]+)(?:\\t?)(.*)\\n" );
+	m_unifiedDiffHeader2.setPattern    ( "\\+\\+\\+ ([^\\t]+)\\t([^\\t]+)(?:\\t?)(.*)\\n" );
+	m_unifiedHunkHeader.setPattern     ( "@@ -([0-9]+)(|,([0-9]+)) \\+([0-9]+)(|,([0-9]+)) @@(?: ?)(.*)\\n" );
+	m_unifiedHunkBodyAdded.setPattern  ( "\\+(.*)" );
+	m_unifiedHunkBodyRemoved.setPattern( "-(.*)" );
+	m_unifiedHunkBodyContext.setPattern( " (.*)" );
+	m_unifiedHunkBodyLine.setPattern   ( "([-+ ])(.*)" );
 }
 
 ParserBase::~ParserBase()
 {
+	if ( m_models )
+		m_models = 0; // dont delete this, i pass it around...
 }
 
 enum Kompare::Format ParserBase::determineFormat()
@@ -319,6 +321,7 @@ bool ParserBase::parseContextHunkBody()
 	// Storing the src part of the hunk for later use
 	QStringList oldLines;
 	for( ; m_diffIterator != m_diffLines.end() && m_contextHunkBodyLine.exactMatch( *m_diffIterator ); ++m_diffIterator ) {
+//		kdDebug(8101) << "Added old line: " << *m_diffIterator << endl;
 		oldLines.append( *m_diffIterator );
 	}
 
@@ -330,15 +333,16 @@ bool ParserBase::parseContextHunkBody()
 	// Storing the dest part of the hunk for later use
 	QStringList newLines;
 	for( ; m_diffIterator != m_diffLines.end() && m_contextHunkBodyLine.exactMatch( *m_diffIterator ); ++m_diffIterator ) {
+//		kdDebug(8101) << "Added new line: " << *m_diffIterator << endl;
 		newLines.append( *m_diffIterator );
 	}
 
 	QString function = m_contextHunkHeader1.cap( 1 );
-//	kdDebug() << "Captured function: " << function << endl;
+//	kdDebug(8101) << "Captured function: " << function << endl;
 	int linenoA      = m_contextHunkHeader2.cap( 1 ).toInt();
-//	kdDebug() << "Source line number: " << linenoA << endl;
+//	kdDebug(8101) << "Source line number: " << linenoA << endl;
 	int linenoB      = m_contextHunkHeader3.cap( 1 ).toInt();
-//	kdDebug() << "Dest   line number: " << linenoB << endl;
+//	kdDebug(8101) << "Dest   line number: " << linenoB << endl;
 
 	DiffHunk* hunk = new DiffHunk( linenoA, linenoB, function );
 
@@ -380,16 +384,17 @@ bool ParserBase::parseContextHunkBody()
 				linenoB++;
 			}
 		}
-		else if(  ( oldIt != oldLines.end() && m_contextHunkBodyContext.exactMatch( *oldIt ) ) ||
-		          ( newIt != newLines.end() && m_contextHunkBodyContext.exactMatch( *newIt ) ) )
+		else if(  ( oldIt == oldLines.end() || m_contextHunkBodyContext.exactMatch( *oldIt ) ) &&
+		          ( newIt == newLines.end() || m_contextHunkBodyContext.exactMatch( *newIt ) ) )
 		{
 //			kdDebug(8101) << "Unchanged: " << endl;
 			diff = new Difference( linenoA, linenoB );
 			// Dont add this diff with addDiff to the model... no unchanged differences allowed in there...
 			diff->setType( Difference::Unchanged );
 			hunk->add( diff );
-			while( ( oldIt != oldLines.end() && m_contextHunkBodyContext.exactMatch( *oldIt ) ) &&
-			       ( newIt != newLines.end() && m_contextHunkBodyContext.exactMatch( *newIt ) ) )
+			while( ( oldIt == oldLines.end() || m_contextHunkBodyContext.exactMatch( *oldIt ) ) &&
+			       ( newIt == newLines.end() || m_contextHunkBodyContext.exactMatch( *newIt ) ) &&
+			       ( oldIt != oldLines.end() || newIt != newLines.end() ) )
 			{
 				QString l;
 				if( oldIt != oldLines.end() )
@@ -436,9 +441,7 @@ bool ParserBase::parseContextHunkBody()
 		}
 		else
 			return false;
-#if INLINE_DIFFERENCES
 		diff->determineInlineDifferences();
-#endif
 	}
 
 	return true;
@@ -504,7 +507,7 @@ bool ParserBase::parseNormalHunkBody()
 
 	return true;
 }
-
+ 
 bool ParserBase::parseRCSHunkBody()
 {
 	return false;
@@ -526,10 +529,24 @@ bool ParserBase::parseUnifiedHunkBody()
 //	kdDebug(8101) << "ParserBase::parseUnifiedHunkBody" << endl;
 
 	int linenoA = 0, linenoB = 0;
+	bool wasNum;
 
 	// Fetching the stuff we need from the hunkheader regexp that was parsed in parseUnifiedHunkHeader();
 	linenoA = m_unifiedHunkHeader.cap( 1 ).toInt();
+	if( !m_unifiedHunkHeader.cap( 3 ).isEmpty() && m_unifiedHunkHeader.cap( 3 ).toInt(&wasNum) == 0 ) {
+		// If a hunk is an insertion or deletion with no context, the line number given
+		// is the one before the hunk. this isn't what we want, so increment it to fix this.
+		if( wasNum == false )
+			return false;
+		linenoA++;
+	}
 	linenoB = m_unifiedHunkHeader.cap( 4 ).toInt();
+	if( !m_unifiedHunkHeader.cap( 6 ).isEmpty() && m_unifiedHunkHeader.cap( 6 ).toInt(&wasNum) == 0 ) {
+		// see above
+		if( wasNum == false )
+			return false;
+		linenoB++;
+	}
 	QString function = m_unifiedHunkHeader.cap( 7 );
 	for ( int i = 0; i < 9; i++ )
 	{
@@ -554,9 +571,8 @@ bool ParserBase::parseUnifiedHunkBody()
 		{	// context
 			for( ; m_diffIterator != m_diffLinesEnd && (*m_diffIterator).startsWith( context ); ++m_diffIterator )
 			{
-				QString line = QString( *m_diffIterator ).remove( 0, 1 );
-				diff->addSourceLine( line );
-				diff->addDestinationLine( line );
+				diff->addSourceLine( QString( *m_diffIterator ).remove( 0, 1 ) );
+				diff->addDestinationLine( QString( *m_diffIterator ).remove( 0, 1 ) );
 				linenoA++;
 				linenoB++;
 			}
@@ -588,9 +604,7 @@ bool ParserBase::parseUnifiedHunkBody()
 				diff->setType( Difference::Change );
 //				kdDebug(8101) << "Change difference" << endl;
 			}
-#if INLINE_DIFFERENCES
 			diff->determineInlineDifferences();
-#endif
 			m_currentModel->addDiff( diff );
 		}
 	}
@@ -605,9 +619,11 @@ DiffModelList* ParserBase::parseContext()
 		while ( parseContextHunkHeader() )
 			parseContextHunkBody();
 		if ( m_currentModel->differenceCount() > 0 )
-			m_models->inSort( m_currentModel );
+			m_models->append( m_currentModel );
 	}
 
+	m_models->sort();
+
 	if ( m_models->count() > 0 )
 	{
 		return m_models;
@@ -626,9 +642,11 @@ DiffModelList* ParserBase::parseEd()
 		while ( parseEdHunkHeader() )
 			parseEdHunkBody();
 		if ( m_currentModel->differenceCount() > 0 )
-			m_models->inSort( m_currentModel );
+			m_models->append( m_currentModel );
 	}
 
+	m_models->sort();
+
 	if ( m_models->count() > 0 )
 	{
 		return m_models;
@@ -647,7 +665,7 @@ DiffModelList* ParserBase::parseNormal()
 		while ( parseNormalHunkHeader() )
 			parseNormalHunkBody();
 		if ( m_currentModel->differenceCount() > 0 )
-			m_models->inSort( m_currentModel );
+			m_models->append( m_currentModel );
 	}
 
 	if ( m_singleFileDiff )
@@ -655,9 +673,11 @@ DiffModelList* ParserBase::parseNormal()
 		while ( parseNormalHunkHeader() )
 			parseNormalHunkBody();
 		if ( m_currentModel->differenceCount() > 0 )
-			m_models->inSort( m_currentModel );
+			m_models->append( m_currentModel );
 	}
 
+	m_models->sort();
+
 	if ( m_models->count() > 0 )
 	{
 		return m_models;
@@ -676,9 +696,11 @@ DiffModelList* ParserBase::parseRCS()
 		while ( parseRCSHunkHeader() )
 			parseRCSHunkBody();
 		if ( m_currentModel->differenceCount() > 0 )
-			m_models->inSort( m_currentModel );
+			m_models->append( m_currentModel );
 	}
 
+	m_models->sort();
+
 	if ( m_models->count() > 0 )
 	{
 		return m_models;
@@ -699,9 +721,11 @@ DiffModelList* ParserBase::parseUnified()
 //		kdDebug(8101) << "New model ready to be analyzed..." << endl;
 //		kdDebug(8101) << " differenceCount() == " << m_currentModel->differenceCount() << endl;
 		if ( m_currentModel->differenceCount() > 0 )
-			m_models->inSort( m_currentModel );
+			m_models->append( m_currentModel );
 	}
 
+	m_models->sort();
+
 	if ( m_models->count() > 0 )
 	{
 		return m_models;
