@@ -161,8 +161,7 @@ bool UMLAssociation::resolveRef() {
 }
 
 void UMLAssociation::saveToXMI( QDomDocument & qDoc, QDomElement & qElement ) {
-    if (m_AssocType == Uml::at_Generalization ||
-            m_AssocType == Uml::at_Realization) {
+    if (m_AssocType == Uml::at_Generalization) {
         QDomElement assocElement = UMLObject::save("UML:Generalization", qDoc);
         assocElement.setAttribute( "discriminator", "" );
         assocElement.setAttribute( "child", ID2STR(getObjectId(A)) );
@@ -170,6 +169,13 @@ void UMLAssociation::saveToXMI( QDomDocument & qDoc, QDomElement & qElement ) {
         qElement.appendChild( assocElement );
         return;
     }
+    if (m_AssocType == Uml::at_Realization) {
+        QDomElement assocElement = UMLObject::save("UML:Abstraction", qDoc);
+        assocElement.setAttribute( "client", ID2STR(getObjectId(A)) );
+        assocElement.setAttribute( "supplier", ID2STR(getObjectId(B)) );
+        qElement.appendChild( assocElement );
+        return;
+    }
     if (m_AssocType == Uml::at_Dependency) {
         QDomElement assocElement = UMLObject::save("UML:Dependency", qDoc);
         assocElement.setAttribute( "client", ID2STR(getObjectId(A)) );
@@ -192,7 +198,8 @@ bool UMLAssociation::load( QDomElement & element ) {
     UMLDoc * doc = UMLApp::app()->getDocument();
     UMLObject * obj[2] = { NULL, NULL };
     if (m_AssocType == Uml::at_Generalization ||
-            m_AssocType == Uml::at_Dependency) {
+        m_AssocType == Uml::at_Realization ||
+        m_AssocType == Uml::at_Dependency) {
         for (unsigned r = Uml::A; r <= Uml::B; r++) {
             const QString fetch = (m_AssocType == Uml::at_Generalization ?
                                    r == Uml::A ? "child" : "parent"
@@ -221,15 +228,9 @@ bool UMLAssociation::load( QDomElement & element ) {
                 QString tag = tempElement.tagName();
                 if (Model_Utils::isCommonXMIAttribute(tag))
                     continue;
-                bool isGeneralization = (m_AssocType == Uml::at_Generalization &&
-                                         (tagEq(tag, "child") || tagEq(tag, "parent") ||
-                                          tagEq(tag, "subtype") || tagEq(tag, "supertype")));
-                bool isDependency = (m_AssocType == Uml::at_Dependency &&
-                                     (tagEq(tag, "client") || tagEq(tag, "supplier")));
-                if (!isGeneralization && !isDependency) {
-                    kdDebug() << "UMLAssociation::load: cannot load " << tag << endl;
-                    continue;
-                }
+                // Permitted tag names:
+                //  roleA: "child" "subtype" "client"
+                //  roleB: "parent" "supertype" "supplier"
                 QString idStr = tempElement.attribute( "xmi.id", "" );
                 if (idStr.isEmpty())
                     idStr = tempElement.attribute( "xmi.idref", "" );
@@ -242,8 +243,8 @@ bool UMLAssociation::load( QDomElement & element ) {
                 }
                 if (idStr.isEmpty()) {
                     kdError() << "UMLAssociation::load (type " << m_AssocType
-                    << ", id " << ID2STR(getID()) << "): "
-                    << "xmi id not given for " << tag << endl;
+                        << ", id " << ID2STR(getID()) << "): "
+                        << "xmi id not given for " << tag << endl;
                     continue;
                 }
                 // Since we know for sure that we're dealing with a non
@@ -256,15 +257,6 @@ bool UMLAssociation::load( QDomElement & element ) {
             }
         }
 
-        // setting the association type:
-        //
-        // In the old days, we could just record this on the association,
-        // and be done with it. But thats not how the UML13.dtd does things.
-        // As a result, we are checking roleA for information about the
-        // parent association (!) which by this point in the parse, should
-        // be set. However, the information that the roles are allowed to have
-        // is not complete, so we need to finish the analysis here.
-
         // its a realization if either endpoint is an interface
         if (m_AssocType == Uml::at_Generalization &&
                 (obj[A] && obj[A]->getBaseType() == Uml::ot_Interface ||
