@@ -39,8 +39,7 @@
 // 3-14-2003: this code developed from the javawriter with parts of the
 // original cppwriter by Luis De la Parra Blum
 
-CppWriter::CppWriter( UMLDoc *parent, const char *name )
-        : SimpleCodeGenerator(parent, name)
+CppWriter::CppWriter()
 {
 
     // set some general parameters for how to generate code in this class
@@ -86,15 +85,8 @@ CppWriter::CppWriter( UMLDoc *parent, const char *name )
 
 CppWriter::~CppWriter() { }
 
-QString CppWriter::getLanguage() {
-    return "C++";
-}
-
-bool CppWriter::isType (QString & type)
-{
-    if (type == "CppWriter")
-        return true;
-    return false;
+Uml::Programming_Language CppWriter::getLanguage() {
+    return Uml::pl_Cpp;
 }
 
 void CppWriter::writeClass(UMLClassifier *c)
@@ -1196,6 +1188,9 @@ void CppWriter::writeOperations(UMLOperationList &oplist, bool isHeaderMethod, Q
         }
         str += " )";
 
+        if (op->getConst())
+            str += " const";
+
         // method body : only gets IF its not in a header
         if (isHeaderMethod && !INLINE_OPERATION_METHODS)
             str +=";"; // terminate now
@@ -1287,8 +1282,8 @@ QString CppWriter::getAttributeVariableName (UMLAttribute *at)
     return fieldName;
 }
 
-void CppWriter::createDefaultDatatypes() {
-    Codegen_Utils::createCppDatatypes();
+QStringList CppWriter::defaultDatatypes() {
+    return Codegen_Utils::cppDatatypes();
 }
 
 const QStringList CppWriter::reservedKeywords() const {
