@@ -21,10 +21,6 @@
 #include "simplecodegenerator.h"
 #include "../umlattributelist.h"
 
-#include <qptrlist.h>
-#include <qstringlist.h>
-
-
 /**
   * class SQLWriter is a code generator for UMLClassifier objects.
   * Create an instance of this class, and feed it a UMLClassifier when
@@ -32,52 +28,45 @@
   * that concept
   */
 class SQLWriter : public SimpleCodeGenerator {
-	Q_OBJECT
+    Q_OBJECT
 public:
 
-	SQLWriter( UMLDoc * parent, const char* name = 0 );
-	virtual ~SQLWriter();
+    SQLWriter();
+    virtual ~SQLWriter();
 
-	/**
-	 * call this method to generate sql code for a UMLClassifier
-	 * @param c the class to generate code for
-	 */
-	virtual void writeClass(UMLClassifier *c);
+    /**
+     * call this method to generate sql code for a UMLClassifier
+     * @param c the class to generate code for
+     */
+    virtual void writeClass(UMLClassifier *c);
 
-	/**
-	 * checks whether type is "SQLWriter"
-	 *
-	 * @param type
-	 */
-	virtual bool isType (QString & type);
+    /**
+     * returns "SQL"
+     */
+    virtual Uml::Programming_Language getLanguage();
 
-	/**
-	 * returns "SQL"
-	 */
-	virtual QString getLanguage();
-
-	/**
-	 * get list of reserved keywords
-	 */
-	virtual const QStringList reservedKeywords() const;
+    /**
+     * get list of reserved keywords
+     */
+    virtual const QStringList reservedKeywords() const;
 
 private:
 
-	/**
-	 * write all attributes for a given class
-	 * @param c the class for which we are generating code
-	 * @param j the stream associated with the output file
-	 */
-	void writeAttributes(UMLClass *c, QTextStream &j);
+    /**
+     * write all attributes for a given class
+     * @param c the class for which we are generating code
+     * @param j the stream associated with the output file
+     */
+    void writeAttributes(UMLClassifier *c, QTextStream &j);
 
-	/**
-	 * Prints out attributes as columns in the table
-	 *
-	 * @param sql the stream we should print to
-	 * @param attributeList the attributes to be printed
-	 * @param first if the attributes are the first one
-	 */
-	void printAttributes(QTextStream& sql, UMLAttributeList attributeList, bool first);
+    /**
+     * Prints out attributes as columns in the table
+     *
+     * @param sql the stream we should print to
+     * @param attributeList the attributes to be printed
+     * @param first if the attributes are the first one
+     */
+    void printAttributes(QTextStream& sql, UMLAttributeList attributeList, bool first);
 };
 
 #endif // SQLWRITER_H
