@@ -77,8 +77,7 @@ static const char *words[] = {
                                  0
                              };
 
-TclWriter::TclWriter(UMLDoc * parent, const char *name)
-        : SimpleCodeGenerator(parent, name)
+TclWriter::TclWriter()
 {
 }
 
@@ -86,18 +85,10 @@ TclWriter::~TclWriter()
 {
 }
 
-QString
+Uml::Programming_Language
 TclWriter::getLanguage()
 {
-    return "Tcl";
-}
-
-bool
-TclWriter::isType(QString & type)
-{
-    if (type == "TclWriter")
-        return true;
-    return false;
+    return Uml::pl_Tcl;
 }
 
 void
@@ -217,7 +208,7 @@ TclWriter::writeHeaderFile(UMLClassifier * c, QFile & fileh)
     }
     // check on enum classes
     if (!classifierInfo->isInterface) {
-        // use tcl-list for enums
+        // use tcl-list for enum's
         if (c->getBaseType() == Uml::ot_Enum) {
             UMLClassifierListItemList litList =
                 c->getFilteredList(Uml::ot_EnumLiteral);
