@@ -22,6 +22,7 @@
 #include "umldoc.h"
 #include "uml.h"
 #include "listpopupmenu.h"
+#include "model_utils.h"
 
 #include <kdebug.h>
 #include <qpainter.h>
@@ -104,8 +105,16 @@ void EntityWidget::draw(QPainter& p, int offsetX, int offsetY) {
     for (entityattribute = list.first(); entityattribute; entityattribute = list.next()) {
         QString text = entityattribute->getName();
         p.setPen( QPen(Qt::black) );
+        UMLEntityAttribute* casted = dynamic_cast<UMLEntityAttribute*>( entityattribute );
+        if( casted && casted->getIndexType() == Uml::Primary )
+        {
+            font.setUnderline( true );
+            p.setFont( font );
+            font.setUnderline( false );
+        }
         p.drawText(offsetX + ENTITY_MARGIN, offsetY + y,
                    fontMetrics.width(text), fontHeight, Qt::AlignVCenter, text);
+        p.setFont( font );
         y+=fontHeight;
     }
 
@@ -172,7 +181,7 @@ QSize EntityWidget::calculateSize() {
 void EntityWidget::slotMenuSelection(int sel) {
     switch(sel) {
     case ListPopupMenu::mt_EntityAttribute:
-        if ( UMLApp::app()->getDocument()->createChildObject(m_pObject, Uml::ot_EntityAttribute) )  {
+        if (Model_Utils::createChildObject(m_pObject, Uml::ot_EntityAttribute) )  {
             UMLApp::app()->getDocument()->setModified();
         }
         break;
