@@ -30,6 +30,7 @@
 
 // forward declarations
 class UMLClassifier;
+class UMLPackage;
 
 namespace Model_Utils {
 
@@ -71,6 +72,31 @@ UMLObject* findUMLObject( UMLObjectList inList, QString name,
                           Uml::Object_Type type = Uml::ot_UMLObject,
                           UMLObject *currentObj = NULL);
 
+/**
+ * Returns a name for the new object, appended with a number
+ * if the default name is taken e.g. new_actor, new_actor_1
+ * etc.
+ * @param type              The object type.
+ * @param prefix    The prefix to use (optional.)
+ *                  If no prefix is given then a type related
+ *                  prefix will be chosen internally.
+ * @param parentPkg The package in which to compare the name (optional.)
+ *                  If not given then comparisons are done in the global scope.
+ */
+QString uniqObjectName(Uml::Object_Type type,
+                       QString prefix = QString::null,
+                       UMLPackage *parentPkg = 0);
+
+/**
+ * Creates an operation, attribute, template, or enum literal
+ * for the parent concept.
+ *
+ * @param o The parent concept
+ * @param type      The type to create
+ * @return  The UMLObject created
+ */
+UMLObject* createChildObject(UMLObject* o, Uml::Object_Type type);
+
 /**
  * Return true if the given tag is a one of the common XMI
  * attributes, such as:
@@ -97,6 +123,16 @@ bool isCommonDataType(QString type);
  */
 int stringToDirection(QString input, Uml::Parameter_Direction & result);
 
+/**
+ * Return string corresponding to the given Uml::Programming_Language.
+ */
+QString progLangToString(Uml::Programming_Language pl);
+
+/**
+ * Return Uml::Programming_Language corresponding to the given string.
+ */
+Uml::Programming_Language stringToProgLang(QString str);
+
 /**
  * Return type of parseOperation()
  */
