@@ -1,7 +1,7 @@
- /*
-  *  copyright (C) 2002-2004
-  *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
-  */
+/*
+ *  copyright (C) 2002-2004
+ *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
+ */
 
 /***************************************************************************
  *                                                                         *
@@ -18,22 +18,22 @@
 #include "umlviewcanvas.h"
 
 UMLViewCanvas::UMLViewCanvas( UMLView * pView ) : QCanvas( pView ) {
-	m_pView = pView;
+    m_pView = pView;
 }
 
 UMLViewCanvas::~UMLViewCanvas() {}
 
 void UMLViewCanvas::drawBackground( QPainter & painter, const QRect & clip ) {
-	QCanvas::drawBackground( painter, clip );
-	if( m_pView -> getShowSnapGrid() ) {
-		painter.setPen( gray );
-		int gridX = m_pView -> getSnapX();
-		int gridY = m_pView -> getSnapY();
-		int numX = width() / gridX;
-		int numY = height() / gridY;
-		for( int x = 0; x <= numX; x++ )
-			for( int y = 0; y < numY; y++ )
-				painter.drawPoint( x * gridX, y * gridY );
-	}
+    QCanvas::drawBackground( painter, clip );
+    if( m_pView -> getShowSnapGrid() ) {
+        painter.setPen( Qt::gray );
+        int gridX = m_pView -> getSnapX();
+        int gridY = m_pView -> getSnapY();
+        int numX = width() / gridX;
+        int numY = height() / gridY;
+        for( int x = 0; x <= numX; x++ )
+            for( int y = 0; y < numY; y++ )
+                painter.drawPoint( x * gridX, y * gridY );
+    }
 }
 
