@@ -33,7 +33,8 @@
 #include "dialogs/settingsdlg.h"
 #include "codedocument.h"
 #include "floatingtext.h"
-
+#include "docwindow.h"
+#include "dialogs/classpropdlg.h"
 #include "clipboard/idchangelog.h"
 
 using namespace Uml;
@@ -103,6 +104,7 @@ UMLWidget& UMLWidget::operator=(const UMLWidget& other) {
     m_pObject = other.m_pObject;
     m_pView = other.m_pView;
     m_pMenu = other.m_pMenu;
+    m_bResizable = other.m_bResizable;
     m_bResizing = other.m_bResizing;
     m_nPressOffsetX = other.m_nPressOffsetX;
     m_nPressOffsetY = other.m_nPressOffsetY;
@@ -344,8 +346,9 @@ void UMLWidget::mousePressEvent(QMouseEvent *me) {
     m_nOldH = height();
     const int m = 10;
     //see if clicked on bottom right corner
-    if( (m_nOldX + m_nPressOffsetX) >= (getX() + width() - m) &&
-        (m_nOldY + m_nPressOffsetY) >= (getY() + height() - m) && me->button() == Qt::LeftButton) {
+    if( m_bResizable && me->button() == Qt::LeftButton &&
+        (m_nOldX + m_nPressOffsetX) >= (getX() + width() - m) &&
+        (m_nOldY + m_nPressOffsetY) >= (getY() + height() - m)) {
         m_bResizing = true;
         m_pView->setCursor(WidgetBase::m_Type == Uml::wt_Message ?
                            KCursor::sizeVerCursor() : KCursor::sizeFDiagCursor());
@@ -446,6 +449,7 @@ void UMLWidget::init() {
     for (int i = 0; i < (int)FT_INVALID; ++i)
         m_pFontMetrics[(UMLWidget::FontType)i] = 0;
 
+    m_bResizable = true;
     m_bResizing = false;
     m_bMouseOver = false;
 
@@ -495,9 +499,9 @@ void UMLWidget::slotMenuSelection(int sel) {
                 wt == wt_Component || wt == wt_Artifact ||
                 wt == wt_Node || wt == wt_Enum || wt == wt_Entity ||
                 (wt == wt_Class && m_pView -> getType() == dt_Class)) {
-            m_pDoc -> showProperties(this);
+            showProperties();
         } else if (wt == wt_Object) {
-            m_pDoc -> showProperties(m_pObject);
+            m_pObject->showProperties();
         } else {
             kdWarning() << "making properties dialogue for unknown widget type" << endl;
         }
@@ -675,7 +679,7 @@ void UMLWidget::setFillColour(const QColor &colour) {
     update();
 }
 
-void UMLWidget::drawSelected(QPainter * p, int offsetX, int offsetY, bool resizeable) {
+void UMLWidget::drawSelected(QPainter * p, int offsetX, int offsetY) {
     int w = width();
     int h = height();
     int s = 4;
@@ -685,7 +689,7 @@ void UMLWidget::drawSelected(QPainter * p, int offsetX, int offsetY, bool resize
     p -> fillRect(offsetX + w - s, offsetY, s, s, brush);
 
     // Draw the resize anchor in the lower right corner.
-    if (resizeable) {
+    if (m_bResizable) {
         brush.setColor(Qt::red);
         const int right = offsetX + w;
         const int bottom = offsetY + h;
@@ -802,6 +806,23 @@ void UMLWidget::adjustUnselectedAssocs(int x, int y)
     }
 }
 
+bool UMLWidget::showProperties() {
+    // will already be selected so make sure docWindow updates the doc
+    // back it the widget
+    DocWindow *docwindow = UMLApp::app()->getDocWindow();
+    docwindow->updateDocumentation( false );
+    ClassPropDlg *dlg = new ClassPropDlg((QWidget*)UMLApp::app(), this);
+
+    bool modified = false;
+    if (dlg->exec()) {
+        docwindow->showDocumentation( getUMLObject() , true );
+        UMLApp::app()->getDocument()->setModified(true);
+        modified = true;
+    }
+    dlg->close(true); //wipe from memory
+    return modified;
+}
+
 void UMLWidget::startPopupMenu( const QPoint &At) {
     slotRemovePopupMenu();
 
